from webspace.cms import constants
from webspace.cms.blocks.common import \
    GalleryBlock, \
    EntryBlock


class GalleryEntry(EntryBlock):
    gallery = GalleryBlock()

    def mock(self, *args, **kwargs):
        gallery = self.get_gallery(*args, **kwargs)
        self.mock_data.update({
            'type': 'gallery',
            'value': {
                'gallery': {
                    'gallery': gallery.id
                }
            }
        })
        return super().mock(*args, **kwargs)

    class Meta:
        template = '%s/entries/gallery.html' % constants.BLOCK_TEMPLATES_PATH
        label = "Gallery"



from .component_text import ComponentTextEntry
from .svg import SvgEntry
from .text import TextEntry
from .image import ImageEntry
from .cards import CardsEntry, StreamCard
from .grid_info import GridInfoEntry
from .medias_line import MediasLineEntry
from .timeline import TimeLineEntry
from .buttons import ButtonsEntry
from .articles import ArticlesEntry
from .embed import EmbedEntry
from .calendly import CalendlyEntry
from .table import TableEntry
from .numbers import NumbersEntry
from .accordion import AccordionEntry
from .form import FormEntry
from .portfolios import PortfoliosEntry
from .gallery import GalleryEntry
from .stream_content import StreamContentEntry
from .gallery_slider import GallerySliderEntry



import os
from fs import path
from .base import BuildableMixin
from django.conf import settings
from django.views.generic import DetailView
from django.core.exceptions import ImproperlyConfigured


class BuildableDetailView(DetailView, BuildableMixin):

    @property
    def build_method(self):
        return self.build_queryset

    def get_url(self, obj):
        if not hasattr(obj, 'get_absolute_url') or not obj.get_absolute_url():
            raise ImproperlyConfigured("No URL configured. You must either \
set a ``get_absolute_url`` method on the %s model or override the %s view's \
``get_url`` method" % (obj.__class__.__name__, self.__class__.__name__))
        return obj.get_absolute_url()

    def get_build_path(self, obj):
        target_path = path.join(settings.BUILD_DIR, self.get_url(obj).lstrip('/'))
        if not self.fs.exists(target_path):
            self.fs.makedirs(target_path)
        return path.join(target_path, 'index.html')

    def set_kwargs(self, obj):
        slug_field = self.get_slug_field()
        self.kwargs = {
            'pk': getattr(obj, 'pk', None),
            slug_field: getattr(obj, slug_field, None),
            # Also alias the slug_field to the key `slug`
            # so it can work for people who just toss that in
            'slug': getattr(obj, slug_field, None),
        }

    def build_object(self, obj):
        self.request = self.create_request(self.get_url(obj))
        self.set_kwargs(obj)
        target_path = self.get_build_path(obj)
        self.build_file(target_path, self.get_content())

    def build_queryset(self):
        [self.build_object(o) for o in self.get_queryset().all()]

    def unbuild_object(self, obj):
        target_path = os.path.split(self.get_build_path(obj))[0]
        if self.fs.exists(target_path):
            self.fs.removetree(target_path)



import os
import json
import string
import random


def generate_secret_key(size=247, chars=string.ascii_letters + string.digits):
    return ''.join(random.choice(chars) for _ in range(size))


def get_package_version(file_path):
    with open(file_path) as package:
        data = json.load(package)
        return data['version']


def run_sentry():
    import sentry_sdk
    from sentry_sdk.integrations.django import DjangoIntegration
    from sentry_sdk.integrations.logging import LoggingIntegration
    from sentry_sdk.integrations.celery import CeleryIntegration
    from sentry_sdk.integrations.redis import RedisIntegration
    import logging
    sentry_sdk.init(
        dsn="https://677252655469434897723bab86b18ef0@o419846.ingest.sentry.io/5336964",
        integrations=[
            DjangoIntegration(),
            LoggingIntegration(
                level=logging.INFO,
                event_level=logging.ERROR
            ),
            CeleryIntegration(),
            RedisIntegration()
        ],
        send_default_pii=True
    )


ALLOWED_HOSTS_DEV = [
    '127.0.0.1',
    'localhost',
    'home'
]

INSTALLED_APPS = [
    'webspace.account',
    'webspace.bakery.apps.BakeryConfig',

    'wagtail.contrib.forms',
    'wagtail.contrib.redirects',
    'wagtail.embeds',
    'wagtail.sites',
    'wagtail.users',
    'wagtail.snippets',
    'wagtail.documents',
    'wagtail.images',
    'wagtail.search',
    'wagtail.admin',
    'wagtail.core',
    'wagtail.contrib.settings',
    'wagtail.contrib.frontend_cache',

    'storages',
    'modelcluster',
    'taggit',
    'django_social_share',
    'wagtail_feeds',

    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.sites',
    "django.contrib.sitemaps",

    'django_user_agents',
    'rosetta',

]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'django_user_agents.middleware.UserAgentMiddleware',
    'django.middleware.gzip.GZipMiddleware',
    'webspace.middleware.ConfigMiddleware',
    'wagtail.contrib.redirects.middleware.RedirectMiddleware',
    'csp.middleware.CSPMiddleware',
]


def get_templates(base_dir, is_webspace, path_webspace):
    return [
        {
            'BACKEND': 'django.template.backends.django.DjangoTemplates',
            'DIRS': [os.path.join(base_dir, 'templates')] if is_webspace else [
                os.path.join(base_dir, 'cms/templates'),
                os.path.join(path_webspace, 'cms/templates'),
            ],
            'OPTIONS': {
                'context_processors': [
                    'django.template.context_processors.debug',
                    'django.template.context_processors.request',
                    'django.contrib.auth.context_processors.auth',
                    'django.contrib.messages.context_processors.messages',
                    'wagtail.contrib.settings.context_processors.settings',
                    'webspace.cms.amp.context_processors.amp'
                ],
                'loaders': [
                    'django.template.loaders.filesystem.Loader',
                    'django.template.loaders.app_directories.Loader',
                ],
                'libraries': {
                    'my': 'webspace.cms.templatetags.my',
                    'my_minify': 'webspace.cms.templatetags.my_minify',
                    'my_amp': 'webspace.cms.templatetags.my_amp',
                    'my_image_color': 'webspace.cms.templatetags.my_image_color',
                }
            },
        },
    ]


AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]

STATICFILES_FINDERS = [
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
]

RICH_TEXT_FEATURES = [
    'h1',
    'h2',
    'h3',
    'h4',
    'bold',
    'italic',
    'link',
    'ol',
    'ul',
    'hr',
    'code-block',
    'blockquote',
    'strikethrough',
    'mark',
    'shadow'
]

LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        'verbose': {
            '()': 'webspace.formatter.DjangoColorsFormatter',
            'format': '[%(asctime)s] %(levelname)s\033[0m \033[1m%(name)s\033[0m (%(module)s.%(funcName)s.L%(lineno)d) -> %(message)s'
        },
        'success': {
            '()': 'webspace.formatter.DjangoColorsFormatter',
            'format': '\033[92m[%(asctime)s] SUCCESS\033[0m \033[1m%(name)s\033[0m (%(module)s.%(funcName)s.L%(lineno)d) -> %(message)s'
        },
        'simple': {
            'format': '%(levelname)s %(message)s'
        },
    },
    'handlers': {
        'null': {
            'level': 'DEBUG',
            'class': 'logging.NullHandler',
        },
        'console': {
            'level': 'DEBUG',
            'class': 'logging.StreamHandler',
            'formatter': 'verbose'
        },
        'success': {
            'level': 'DEBUG',
            'class': 'logging.StreamHandler',
            'formatter': 'success'
        },
        'mail_admins': {
            'level': 'ERROR',
            'class': 'django.utils.log.AdminEmailHandler',
        },
    },
    'loggers': {
        'django': {
            'handlers': ['console'],
            'propagate': True,
            'level': 'INFO',
        },
        'django.db.backends': {
            'handlers': ['null'],
            'propagate': False,
            'level': 'DEBUG',
        },
        'aws': {
            'handlers': ['console'],
            'propagate': True,
            'level': 'DEBUG',
        },
        'cms': {
            'handlers': ['success'],
            'propagate': True,
            'level': 'DEBUG',
        },
        'email': {
            'level': 'DEBUG',
            'propagate': True,
            'handlers': ['console'],
        },
        'bakery': {
            'level': 'DEBUG',
            'propagate': True,
            'handlers': ['console'],
        },
        'amp': {
            'level': 'DEBUG',
            'propagate': True,
            'handlers': ['console'],
        },
        'api': {
            'level': 'DEBUG',
            'propagate': True,
            'handlers': ['console'],
        },
        'celery': {
            'level': 'DEBUG',
            'propagate': True,
            'handlers': ['console'],
        },
        'minify_schema': {
            'level': 'DEBUG',
            'propagate': True,
            'handlers': ['console'],
        },
    }
}



from contextlib import contextmanager
from threading import local

# FIXME: For Django 3.0 support, replace this with asgiref.Local
_amp_mode_active = local()


@contextmanager
def activate_amp_mode():
    _amp_mode_active.value = True
    try:
        yield
    finally:
        del _amp_mode_active.value


def amp_mode_active():
    return hasattr(_amp_mode_active, 'value')



import logging
import os

from django.conf import settings
from django.core.handlers.base import BaseHandler
from django.test.client import RequestFactory
from wagtail.core.models import Page

from webspace.loader import get_model
from webspace.bakery.views import BuildableDetailView
from webspace.bakery.abstract import WagtailPageBakeryModel
from webspace.api import API

logger = logging.getLogger('bakery')

USER_AGENT_DESKTOP = "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/81.0.4044.129 Safari/537.36"
USER_AGENT_MOBILE = "Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/13.0.3 Mobile/15E148 Safari/604.1"


class WagtailBakeryView(BuildableDetailView):

    def __init__(self, *args, **kwargs):
        self.handler = BaseHandler()
        self.handler.load_middleware()
        self.request = None
        super().__init__(*args, **kwargs)

    def get(self, request):
        response = self.handler.get_response(request)
        return response

    def get_content(self, obj):
        response = self.get(self.request)
        if hasattr(response, 'render'):
            return response.render().content
        if hasattr(response, 'content'):
            return response.content
        raise AttributeError(
            "'%s' object has no attribute 'render' or 'content'" % response)

    def get_build_path(self, obj):
        url = self.get_url(obj)
        site = self.get_site(obj)
        build_path = os.path.join(settings.BUILD_DIR, site.hostname, url[1:])
        os.path.exists(build_path) or os.makedirs(build_path)
        return os.path.join(build_path, 'index.html')

    def get_url(self, obj):
        return obj.relative_url(self.get_site(obj))

    def get_path(self, obj):
        return obj.path

    def build_object(self, obj):
        logger.debug("Building %s" % obj)

        self.build_object_env(obj)
        self.build_object_env(obj, mobile=True)
        self.build_object_env(obj, amp=True)
        self.build_object_env(obj, mobile=True, amp=True)

    def build_object_env(self, obj, amp=False, mobile=False):
        # Fix create page root
        if self.get_url(obj):
            site = self.get_site(obj)
            user_agent = USER_AGENT_MOBILE if mobile else USER_AGENT_DESKTOP
            pre_url = '/amp' if amp else ''
            url = pre_url + self.get_url(obj) + '?build=true'
            logger.debug("Building %s:%s" % (site.hostname, str(site.port) + url))
            self.request = RequestFactory(
                SERVER_NAME=site.hostname,
                SERVER_PORT=str(site.port)
            ).get(url, HTTP_USER_AGENT=user_agent)
            self.set_kwargs(obj)
            path = self.get_build_path(obj)
            if mobile:
                path = path.replace('.html', '-mobile.html')

            content = self.get_content(obj)
            if amp:
                path = path.replace('.html', '-amp.html')
                content = API.request(
                    '/amp/transform',
                    {'html': content.decode()}
                )
            self.build_file(path, content)

    def build_queryset(self):
        for item in self.get_queryset().all():
            url = self.get_url(item)
            if url is not None:
                self.build_object(item)

    def get_site(self, obj):
        return obj.get_site()

    class Meta:
        abstract = True


class AllBuildablePagesView(WagtailBakeryView):

    def get_queryset(self):
        return Page.objects.all() \
            .public() \
            .type(WagtailPageBakeryModel) \
            .live()


class ATagPagesView(WagtailBakeryView):
    model_index = None
    model_tag = None

    def get_site(self, obj):
        return obj.content_object.get_site()

    def get_url(self, obj):
        site = obj.content_object.get_site()
        index_blog = self.model_index.objects.in_site(site).first()
        if index_blog:
            blog_index_url = index_blog.relative_url(site)
            return '%s' % blog_index_url + 'tags/%s' % obj.tag.slug + '/'
        return None

    def get_queryset(self):
        return self.model_tag.objects.all().distinct()


class BlogIndexTagPagesView(ATagPagesView):
    model_index = get_model('cms', 'BlogIndexPage')
    model_tag = get_model('cms', 'BlogPageTag')


class PortfolioIndexTagPagesView(ATagPagesView):
    model_index = get_model('cms', 'PortfolioIndexPage')
    model_tag = get_model('cms', 'PortfolioPageTag')



# Generated by Django 3.0.7 on 2020-07-06 18:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0007_auto_20200706_1835'),
    ]

    operations = [
        migrations.AddField(
            model_name='form',
            name='inline',
            field=models.BooleanField(default=False),
        ),
    ]



from django.template import (Library, Node)
import json
import logging


logger = logging.getLogger('minify_schema')
register = Library()


class MinifySchema(Node):

    def __init__(self, nodelist):
        self.nodelist = nodelist

    def render(self, context):
        ld = self.nodelist.render(context)
        try:
            return json.dumps(json.loads(ld))
        except Exception:
            logger.error(str(ld))
            return ''


@register.tag('minify_schema')
def minify_schema(parser, token):
    nodelist = parser.parse(('endminify_schema',))
    parser.delete_first_token()
    return MinifySchema(
        nodelist,
    )



from webspace.cms import constants
from webspace.cms.blocks.common import \
    EntryBlock, \
    SvgWithSizeBlock


class SvgEntry(EntryBlock):
    svg = SvgWithSizeBlock()

    def mock(self, force_file=None, size='m', *args, **kwargs):
        if 'theme' in kwargs:
            file = self.SVG_CONTENT_WIDTH_LIGHT \
                if kwargs['theme'] == constants.THEME_LIGHT else self.SVG_CONTENT_WIDTH_SPACE
        else:
            file = self.SVG_CONTENT_WIDTH_LIGHT
        self.mock_data.update({
            'type': 'svg',
            'value': {
                'svg': {
                    'file': self.file(file if not force_file else force_file).id,
                    'size': size
                }
            }
        })
        return super().mock(*args, **kwargs)

    class Meta:
        template = '%s/entries/svg.html' % constants.BLOCK_TEMPLATES_PATH
        label = "Svg"
        icon = 'image'



from wagtail.core import blocks

from webspace.cms import constants
from webspace.cms.blocks.choice import AlignTextChoiceBlock
from webspace.cms.blocks.common import ButtonsBlock, EntryBlock


class ButtonsEntry(EntryBlock):
    align = AlignTextChoiceBlock(required=False)
    buttons = ButtonsBlock()

    def mock(self, btn_one=constants.BUTTON_SECONDARY_FULL, btn_two=constants.BUTTON_SECONDARY, align='left',
             *args, **kwargs):
        self.mock_data.update({
            'type': 'buttons',
            'value': {
                'buttons': [
                    {
                        'type': 'button',
                        'value': self.button(btn_one)
                    },
                    {
                        'type': 'button',
                        'value': self.button(btn_two)
                    },
                ],
                'align': align
            }
        })
        return super().mock(*args, **kwargs)

    class Meta:
        template = '%s/entries/buttons.html' % constants.BLOCK_TEMPLATES_PATH
        label = "Buttons"



from webspace.cms.blocks.choice import AlignTextChoiceBlock
from webspace.cms import constants
from webspace.cms.blocks.common import \
    TextBlock, \
    EntryBlock


class TextEntry(EntryBlock):
    align = AlignTextChoiceBlock(required=False)
    text = TextBlock()

    def mock(self, txt=None, size='big', align=None, *args, **kwargs):
        self.mock_data.update({
            'type': 'text',
            'value': {
                'text': {
                    'value': txt if txt else eval('self.' + size),
                },
                'align': align
            }
        })
        return super().mock(*args, **kwargs)

    class Meta:
        template = '%s/entries/text.html' % constants.BLOCK_TEMPLATES_PATH
        label = "Text"
        icon = 'edit'



from webspace.cms import constants
from webspace.cms.blocks.common import \
    EntryBlock, \
    GallerySliderBlock


class GallerySliderEntry(EntryBlock):
    gallery = GallerySliderBlock()

    class Meta:
        template = '%s/entries/gallery_slider.html' % constants.BLOCK_TEMPLATES_PATH
        label = "Gallery Slider"



from wagtail.core import blocks

from webspace.cms.blocks.choice import AlignTextChoiceBlock
from webspace.cms import constants
from webspace.cms.blocks.common import \
    TextBlock, \
    SvgWithSizeBlock, \
    ImageWithSizeBlock, \
    ButtonBlock, \
    EntryBlock, \
    EmbedWithSizeBlock, \
    FormBlock, \
    GallerySliderBlock


class ComponentTextEntry(EntryBlock):
    amp_scripts = ['iframe', 'form']
    titles = TextBlock(label="Titres")
    text = TextBlock(label="Description")
    reverse = blocks.BooleanBlock(required=False, help_text="Permet de d'intervertir le component et la zone de texte")
    section = blocks.BooleanBlock(required=False, help_text="Permet de sectionner la zone de texte")
    animation = blocks.BooleanBlock(required=False, help_text="Animation")
    align = AlignTextChoiceBlock(required=False)
    component = blocks.StreamBlock(
        [
            ('svg', SvgWithSizeBlock()),
            ('image', ImageWithSizeBlock()),
            ('embed', EmbedWithSizeBlock()),
            ('form', FormBlock()),
            ('gallery_slider', GallerySliderBlock())
        ],
        max_num=1,
        required=False
    )
    buttons = blocks.StreamBlock(
        [
            ('button', ButtonBlock()),
        ],
        max_num=2, required=False
    )

    def mock(self, component='svg', align=None,
             section=False, reverse=False, size_component='m', button_1=constants.BUTTON_PRIMARY_FULL, button_2=None,
             *args, **kwargs):
        if component == 'svg':
            if 'theme' in kwargs:
                file = self.SVG_SQUARE_LIGHT if kwargs['theme'] == constants.THEME_LIGHT else self.SVG_SQUARE_SPACE
            else:
                file = self.SVG_SQUARE_SPACE
        else:
            if 'theme' in kwargs:
                file = self.IMG_SQUARE_LIGHT if kwargs['theme'] == constants.THEME_LIGHT else self.IMG_SQUARE_SPACE
            else:
                file = self.IMG_SQUARE_SPACE
        ret = {
            'type': 'component_text',
            'value': {
                'titles': {'value': self.h1},
                'text': {
                    'value': self.normal
                },
                'component': [{
                    'type': component,
                    'value': {
                        'file': self.file(file).id,
                        'size': size_component
                    },
                }],
                'buttons': [],
                'reverse': reverse,
                'align': align,
                'section': section
            }
        }
        if component == 'embed':
            ret['value']['component'] = [{
                'type': 'embed',
                'value': {
                    'link': self.URL_EMBED,
                    'size': size_component
                }
            }]
        if component == 'form':
            form = self.get_form('small', 2, head_text=False)
            ret['value']['component'] = [{
                'type': 'form',
                'value': {
                    'form': form.id,
                }
            }]
        if button_1:
            ret['value']['buttons'].append({
                'type': 'button',
                'value': self.button(button_1)
            })
        if button_2:
            ret['value']['buttons'].append({
                'type': 'button',
                'value': self.button(m_type=button_2)
            })
        self.mock_data.update(ret)
        return super().mock(*args, **kwargs)

    class Meta:
        template = '%s/entries/component_text.html' % constants.BLOCK_TEMPLATES_PATH
        label = "Component Text"



from django.db import models
import django.forms
from django.conf import settings
from django.template.loader import render_to_string
from django.utils.safestring import mark_safe
from django.utils.translation import gettext as _

from wagtail.admin.edit_handlers import (InlinePanel, FieldPanel, MultiFieldPanel)
from wagtail.contrib.forms.models import FormBuilder, WagtailAdminFormPageForm
from wagtail.contrib.forms.models import AbstractFormField
from wagtail.core.models import Page
from wagtail.admin.edit_handlers import TabbedInterface, ObjectList, PageChooserPanel
from wagtail.core import fields
from wagtail.admin.edit_handlers import EditHandler
from wagtail.admin.edit_handlers import StreamFieldPanel

from modelcluster.models import ClusterableModel
from modelcluster.fields import ParentalKey

from webspace.loader import get_model, get_class
from webspace.cms import constants


class MyFormBuilder(FormBuilder):

    def create_singleline_field(self, field, options):
        options['max_length'] = 255
        return django.forms.CharField(
            widget=django.forms.TextInput(attrs={
                'placeholder': field.placeholder,
                'required': field.required
            }),
            **options
        )

    def create_multiline_field(self, field, options):
        return django.forms.CharField(
            widget=django.forms.Textarea(attrs={
                'placeholder': field.placeholder,
                'required': field.required
            }),
            **options
        )

    def create_email_field(self, field, options):
        return django.forms.EmailField(
            widget=django.forms.EmailInput(attrs={
                'placeholder': field.placeholder,
                'required': field.required
            }),
            **options
        )

    def create_url_field(self, field, options):
        return django.forms.URLField(
            widget=django.forms.URLInput(attrs={
                'placeholder': field.placeholder,
                'required': field.required
            }),
            **options
        )

    def create_number_field(self, field, options):
        return django.forms.DecimalField(
            widget=django.forms.NumberInput(attrs={
                'placeholder': field.placeholder,
                'required': field.required
            }),
            **options
        )

    def create_checkbox_field(self, field, options):
        return django.forms.BooleanField(
            widget=django.forms.CheckboxInput(attrs={
                'placeholder': field.placeholder,
                'required': field.required
            }),
            **options
        )

    def create_date_field(self, field, options):
        return django.forms.DateField(
            widget=django.forms.DateInput(attrs={
                'placeholder': field.placeholder,
                'required': field.required
            }),
            **options
        )

    def create_datetime_field(self, field, options):
        return django.forms.DateTimeField(
            widget=django.forms.DateTimeInput(attrs={
                'placeholder': field.placeholder,
                'required': field.required
            }),
            **options
        )

    def get_field_options(self, field):
        options = super().get_field_options(field)
        return options


class AFormField(AbstractFormField):
    form = ParentalKey('Form', related_name='form_fields')
    placeholder = models.CharField(verbose_name='Placeholder', max_length=255, blank=True)
    """
    icon = models.ForeignKey(
        'cms.IconSnippet',
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name='+',
        verbose_name="Icon"
    )
    """

    panels = AbstractFormField.panels + [
        FieldPanel('placeholder'),
        #  SnippetChooserPanel('icon')
    ]

    class Meta:
        abstract = True
        app_label = 'cms'

    def get_verbose_name(self):
        return ''


class FormSubmissionsPanel(EditHandler):
    template = "wagtailforms/edit_handlers/form_responses_panel.html"

    def render(self):
        FormSubmission = get_model('cms', 'FormSubmission')
        submissions = FormSubmission.objects.filter(form=self.instance)
        submission_count = submissions.count()

        if not submission_count:
            return ''

        return mark_safe(render_to_string(self.template, {
            'self': self,
            'submission_count': submission_count,
            'last_submit_time': submissions.order_by('submit_time').last().submit_time,
            'last_submissions': submissions.order_by('submit_time').all()[:10],
        }))

    def on_model_bound(self):
        if not self.heading:
            self.heading = '%s submissions' % self.model.get_verbose_name()


ActionManager = get_class('cms.blocks.actions', 'ActionManager')
action_manager = ActionManager()


class AForm(ClusterableModel):
    template = "wagtailforms/edit_handlers/form_responses_panel.html"

    base_form_class = WagtailAdminFormPageForm
    form_builder = MyFormBuilder
    submissions_list_view_class = None
    help_text = models.CharField(verbose_name="Nom du formulaire", max_length=100, default='', blank=True)
    text = fields.RichTextField(
        verbose_name="Texte avant le formulaire",
        default='',
        blank=True,
        features=settings.RICH_TEXT_FEATURES
    )
    text_align = models.CharField(
        choices=constants.ALIGN_TEXT_CHOICES,
        default=constants.ALIGN_TEXT_LEFT,
        max_length=100,
        help_text="Permet de changer le theme"
    )
    inline = models.BooleanField(default=False)

    button_text = models.CharField(
        verbose_name="Bouton text",
        max_length=250,
        default='Submit',
        blank=True
    )
    button_theme = models.CharField(
        verbose_name="Bouton theme",
        choices=constants.BUTTON_CHOICES,
        max_length=250,
        default=constants.BUTTON_PRIMARY_FULL,
        blank=True
    )

    redirection_url = models.CharField(verbose_name="Url de redirection", max_length=250, default='', blank=True)
    redirection_page = models.ForeignKey(
        Page,
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name='+',
        verbose_name="Page de redirection après un formulaire validé"
    )

    animation = models.BooleanField(default=False)

    actions = action_manager.get_actions()

    fields_panel = [
        InlinePanel("form_fields", label="Menu Items")
    ]

    settings_panel = [
        FieldPanel("help_text"),
        MultiFieldPanel([
            FieldPanel("text"),
            FieldPanel("text_align"),
        ], "Text du haut"),
        MultiFieldPanel([
            FieldPanel("button_text"),
            FieldPanel('button_theme'),
        ], "Bouton"),
        MultiFieldPanel([
            PageChooserPanel("redirection_page"),
            FieldPanel('redirection_url'),
        ], "Redirection"),
        FieldPanel("inline"),
        FieldPanel("animation")
    ]

    submissions_panel = [
        FormSubmissionsPanel(),
    ]

    actions_panel = [
        StreamFieldPanel('actions'),
    ]

    edit_handler = TabbedInterface([
        ObjectList(fields_panel, heading='Champs'),
        ObjectList(settings_panel, heading='Paramètres'),
        ObjectList(submissions_panel, heading='Soumissions'),
        ObjectList(actions_panel, heading='Actions'),
    ])

    class Meta:
        abstract = True
        app_label = 'cms'

    def __str__(self):
        return self.help_text

    def get_form_fields(self):
        return self.form_fields.all().order_by('sort_order')

    def get_form_class(self):
        fb = self.form_builder(self.get_form_fields())
        return fb.get_form_class()

    def get_form_parameters(self):
        return {}

    def get_form(self, *args, **kwargs):
        form_class = self.get_form_class()
        form_params = self.get_form_parameters()
        form_params.update(kwargs)
        toto = form_class(*args, **form_params)
        return toto

    def get_verbose_name():
        return ''


from wagtail.contrib.forms.models import AbstractFormSubmission


class AFormSubmission(AbstractFormSubmission):
    form = models.ForeignKey('cms.Form', related_name='submissions_form', on_delete=models.CASCADE)
    page = models.ForeignKey(Page, related_name='submissions_page', on_delete=models.CASCADE)

    class Meta:
        abstract = True
        app_label = 'cms'



# Generated by Django 3.0.7 on 2020-07-24 18:11

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='TaskBuild',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('date_start', models.DateTimeField(auto_now=True, null=True)),
                ('date_end', models.DateTimeField(blank=True, null=True)),
                ('task_id', models.CharField(blank=True, default=None, max_length=100, null=True)),
                ('ready', models.BooleanField(default=False)),
            ],
            options={
                'ordering': ['-date_start'],
            },
        ),
    ]



# Generated by Django 3.0.7 on 2020-07-28 17:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0015_auto_20200727_2232'),
    ]

    operations = [
        migrations.AddField(
            model_name='webspacesettings',
            name='button_view_all_articles',
            field=models.CharField(blank=True, default='', max_length=100),
        ),
        migrations.AddField(
            model_name='webspacesettings',
            name='button_view_all_portfolios',
            field=models.CharField(blank=True, default='', max_length=100),
        ),
    ]



# Generated by Django 3.0.7 on 2020-06-30 13:58

import datetime
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import modelcluster.contrib.taggit
import modelcluster.fields
import taggit.managers
import wagtail.core.blocks
import wagtail.core.fields
import wagtail.core.models
import wagtail.documents.blocks
import wagtail.images.blocks
import wagtail.search.index
import wagtail.snippets.blocks
import webspace.cms.amp.mixins
import webspace.cms.blocks.static.social_share
import webspace.cms.forms.abstract


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('taggit', '0003_taggeditem_add_unique_index'),
        ('wagtailcore', '0045_assign_unlock_grouppagepermission'),
        ('wagtailimages', '0022_uploadedimage'),
    ]

    operations = [
        migrations.CreateModel(
            name='Form',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('help_text', models.CharField(blank=True, default='', max_length=100, verbose_name='Nom du formulaire')),
                ('text', wagtail.core.fields.RichTextField(blank=True, default='', verbose_name='Texte avant le formulaire')),
                ('button_text', models.CharField(blank=True, default='Submit', max_length=250, verbose_name='Bouton text')),
                ('button_theme', models.CharField(blank=True, choices=[('primary-light', 'Primary Light'), ('primary-full', 'Primary Full'), ('secondary-light', 'Secondary Light'), ('secondary-full', 'Secondary Full'), ('tertiary-light', 'Tertiary Light'), ('tertiary-full', 'Tertiary Full')], default='primary-full', max_length=250, verbose_name='Bouton theme')),
                ('redirection_url', models.CharField(blank=True, default='', max_length=250, verbose_name='Url de redirection')),
                ('actions', wagtail.core.fields.StreamField([('email', wagtail.core.blocks.StructBlock([('email_receiver', wagtail.core.blocks.CharBlock(required=False))]))], blank=True)),
                ('redirection_page', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailcore.Page', verbose_name='Page de redirection après un formulaire validé')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='GenericPage',
            fields=[
                ('page_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='wagtailcore.Page')),
                ('theme', models.CharField(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], default='space', help_text='Permet de changer le theme du header et du footer', max_length=100)),
                ('breadcrumb', models.BooleanField(default=True, help_text='Ajoute la page dans le sitemap et génère un schéma Breadcrumb', verbose_name='Public pour Google')),
                ('schemas', wagtail.core.fields.StreamField([('how_to', wagtail.core.blocks.StructBlock([('name', wagtail.core.blocks.CharBlock(required=True)), ('description', wagtail.core.blocks.CharBlock(required=True)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Image 500x500', required=True)), ('step', wagtail.core.blocks.StreamBlock([('step', wagtail.core.blocks.StructBlock([('text', wagtail.core.blocks.CharBlock(required=True)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Image 500x500', required=False)), ('name', wagtail.core.blocks.CharBlock(required=True)), ('url', wagtail.core.blocks.URLBlock(required=False))]))]))])), ('faq_page', wagtail.core.blocks.StructBlock([('questions', wagtail.core.blocks.StreamBlock([('questions', wagtail.core.blocks.StructBlock([('question', wagtail.core.blocks.CharBlock(required=True)), ('answer', wagtail.core.blocks.CharBlock(required=True))]))]))]))], blank=True)),
                ('body', wagtail.core.fields.StreamField([('svg', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('svg', wagtail.core.blocks.StructBlock([('file', wagtail.documents.blocks.DocumentChooserBlock(required=False)), ('size', wagtail.core.blocks.ChoiceBlock(choices=[('xs', 'XS'), ('s', 'S'), ('m', 'M'), ('l', 'L'), ('x', 'X'), ('xl', 'XL'), ('full', 'Full')], required=False))]))])), ('image', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('image', wagtail.core.blocks.StructBlock([('file', wagtail.images.blocks.ImageChooserBlock(label='Image 500x500', required=False)), ('size', wagtail.core.blocks.ChoiceBlock(choices=[('xs', 'XS'), ('s', 'S'), ('m', 'M'), ('l', 'L'), ('x', 'X'), ('xl', 'XL'), ('full', 'Full')], required=False))]))])), ('text', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('text', wagtail.core.blocks.StructBlock([('value', wagtail.core.blocks.RichTextBlock(features=['h1', 'h2', 'h3', 'h4', 'bold', 'italic', 'link', 'ol', 'ul', 'hr', 'code-block', 'blockquote', 'strikethrough', 'mark'], required=False))])), ('align', wagtail.core.blocks.ChoiceBlock(choices=[(None, 'Unset'), ('left', 'Left'), ('center', 'Center'), ('right', 'Right'), ('justify', 'Justify')], required=False))])), ('cards', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('carousel', wagtail.core.blocks.BooleanBlock(required=False)), ('carousel_cta', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('cards', wagtail.core.blocks.StreamBlock([('custom', wagtail.core.blocks.StructBlock([('text', wagtail.core.blocks.StructBlock([('value', wagtail.core.blocks.RichTextBlock(features=['h1', 'h2', 'h3', 'h4', 'bold', 'italic', 'link', 'ol', 'ul', 'hr', 'code-block', 'blockquote', 'strikethrough', 'mark'], required=False))])), ('button', wagtail.core.blocks.StructBlock([('text', wagtail.core.blocks.CharBlock(required=False)), ('link', wagtail.core.blocks.URLBlock(required=False)), ('page', wagtail.core.blocks.PageChooserBlock(required=False)), ('open_new_tab', wagtail.core.blocks.BooleanBlock(default=False, required=False)), ('type', wagtail.core.blocks.ChoiceBlock(choices=[('primary-light', 'Primary Light'), ('primary-full', 'Primary Full'), ('secondary-light', 'Secondary Light'), ('secondary-full', 'Secondary Full'), ('tertiary-light', 'Tertiary Light'), ('tertiary-full', 'Tertiary Full')]))])), ('icon', wagtail.core.blocks.StructBlock([('file', wagtail.documents.blocks.DocumentChooserBlock(required=False)), ('size', wagtail.core.blocks.ChoiceBlock(choices=[('xs', 'XS'), ('s', 'S'), ('m', 'M'), ('l', 'L'), ('x', 'X'), ('xl', 'XL'), ('full', 'Full')], required=False))])), ('media', wagtail.core.blocks.StreamBlock([('svg', wagtail.core.blocks.StructBlock([('file', wagtail.documents.blocks.DocumentChooserBlock(required=False)), ('size', wagtail.core.blocks.ChoiceBlock(choices=[('xs', 'XS'), ('s', 'S'), ('m', 'M'), ('l', 'L'), ('x', 'X'), ('xl', 'XL'), ('full', 'Full')], required=False))])), ('image', wagtail.core.blocks.StructBlock([('file', wagtail.images.blocks.ImageChooserBlock(label='Image 500x500', required=False)), ('size', wagtail.core.blocks.ChoiceBlock(choices=[('xs', 'XS'), ('s', 'S'), ('m', 'M'), ('l', 'L'), ('x', 'X'), ('xl', 'XL'), ('full', 'Full')], required=False))]))], max_num=1, required=False))]))], min_num=1))])), ('component_text', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('titles', wagtail.core.blocks.StructBlock([('value', wagtail.core.blocks.RichTextBlock(features=['h1', 'h2', 'h3', 'h4', 'bold', 'italic', 'link', 'ol', 'ul', 'hr', 'code-block', 'blockquote', 'strikethrough', 'mark'], required=False))])), ('text', wagtail.core.blocks.StructBlock([('value', wagtail.core.blocks.RichTextBlock(features=['h1', 'h2', 'h3', 'h4', 'bold', 'italic', 'link', 'ol', 'ul', 'hr', 'code-block', 'blockquote', 'strikethrough', 'mark'], required=False))])), ('reverse', wagtail.core.blocks.BooleanBlock(help_text="Permet de d'intervertir le component et la zone de texte", required=False)), ('section', wagtail.core.blocks.BooleanBlock(help_text='Permet de sectionner la zone de texte', required=False)), ('align', wagtail.core.blocks.ChoiceBlock(choices=[(None, 'Unset'), ('left', 'Left'), ('center', 'Center'), ('right', 'Right'), ('justify', 'Justify')], required=False)), ('component', wagtail.core.blocks.StreamBlock([('svg', wagtail.core.blocks.StructBlock([('file', wagtail.documents.blocks.DocumentChooserBlock(required=False)), ('size', wagtail.core.blocks.ChoiceBlock(choices=[('xs', 'XS'), ('s', 'S'), ('m', 'M'), ('l', 'L'), ('x', 'X'), ('xl', 'XL'), ('full', 'Full')], required=False))])), ('image', wagtail.core.blocks.StructBlock([('file', wagtail.images.blocks.ImageChooserBlock(label='Image 500x500', required=False)), ('size', wagtail.core.blocks.ChoiceBlock(choices=[('xs', 'XS'), ('s', 'S'), ('m', 'M'), ('l', 'L'), ('x', 'X'), ('xl', 'XL'), ('full', 'Full')], required=False))])), ('embed', wagtail.core.blocks.StructBlock([('link', wagtail.core.blocks.URLBlock(required=False)), ('size', wagtail.core.blocks.ChoiceBlock(choices=[('xs', 'XS'), ('s', 'S'), ('m', 'M'), ('l', 'L'), ('x', 'X'), ('xl', 'XL'), ('full', 'Full')], required=False))])), ('form', wagtail.core.blocks.StructBlock([('form', wagtail.snippets.blocks.SnippetChooserBlock('cms.Form', required=True))]))], max_num=1)), ('buttons', wagtail.core.blocks.StreamBlock([('button', wagtail.core.blocks.StructBlock([('text', wagtail.core.blocks.CharBlock(required=False)), ('link', wagtail.core.blocks.URLBlock(required=False)), ('page', wagtail.core.blocks.PageChooserBlock(required=False)), ('open_new_tab', wagtail.core.blocks.BooleanBlock(default=False, required=False)), ('type', wagtail.core.blocks.ChoiceBlock(choices=[('primary-light', 'Primary Light'), ('primary-full', 'Primary Full'), ('secondary-light', 'Secondary Light'), ('secondary-full', 'Secondary Full'), ('tertiary-light', 'Tertiary Light'), ('tertiary-full', 'Tertiary Full')]))]))], max_num=2, required=False))])), ('grid_info', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('infos', wagtail.core.blocks.StreamBlock([('svg_info', wagtail.core.blocks.StructBlock([('file', wagtail.documents.blocks.DocumentChooserBlock(required=False)), ('title', wagtail.core.blocks.CharBlock()), ('text_hover', wagtail.core.blocks.StructBlock([('value', wagtail.core.blocks.RichTextBlock(features=['h1', 'h2', 'h3', 'h4', 'bold', 'italic', 'link', 'ol', 'ul', 'hr', 'code-block', 'blockquote', 'strikethrough', 'mark'], required=False))]))])), ('image_info', wagtail.core.blocks.StructBlock([('file', wagtail.images.blocks.ImageChooserBlock(label='Image 500x500', required=False)), ('title', wagtail.core.blocks.CharBlock()), ('text_hover', wagtail.core.blocks.StructBlock([('value', wagtail.core.blocks.RichTextBlock(features=['h1', 'h2', 'h3', 'h4', 'bold', 'italic', 'link', 'ol', 'ul', 'hr', 'code-block', 'blockquote', 'strikethrough', 'mark'], required=False))]))]))], min_num=1))])), ('medias_line', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('medias', wagtail.core.blocks.StreamBlock([('svg_label', wagtail.core.blocks.StructBlock([('file', wagtail.documents.blocks.DocumentChooserBlock(required=False)), ('label', wagtail.core.blocks.CharBlock(required=False)), ('page', wagtail.core.blocks.PageChooserBlock(required=False)), ('link', wagtail.core.blocks.URLBlock(required=False))])), ('image_label', wagtail.core.blocks.StructBlock([('file', wagtail.images.blocks.ImageChooserBlock(label='Image 500x500', required=False)), ('label', wagtail.core.blocks.CharBlock(required=False)), ('page', wagtail.core.blocks.PageChooserBlock(required=False)), ('link', wagtail.core.blocks.URLBlock(required=False))]))], min_num=1))])), ('timeline', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('items', wagtail.core.blocks.StreamBlock([('text', wagtail.core.blocks.StructBlock([('value', wagtail.core.blocks.RichTextBlock(features=['h1', 'h2', 'h3', 'h4', 'bold', 'italic', 'link', 'ol', 'ul', 'hr', 'code-block', 'blockquote', 'strikethrough', 'mark'], required=False))]))], min_num=1))])), ('buttons', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('align', wagtail.core.blocks.ChoiceBlock(choices=[(None, 'Unset'), ('left', 'Left'), ('center', 'Center'), ('right', 'Right'), ('justify', 'Justify')], required=False)), ('buttons', wagtail.core.blocks.StreamBlock([('button', wagtail.core.blocks.StructBlock([('text', wagtail.core.blocks.CharBlock(required=False)), ('link', wagtail.core.blocks.URLBlock(required=False)), ('page', wagtail.core.blocks.PageChooserBlock(required=False)), ('open_new_tab', wagtail.core.blocks.BooleanBlock(default=False, required=False)), ('type', wagtail.core.blocks.ChoiceBlock(choices=[('primary-light', 'Primary Light'), ('primary-full', 'Primary Full'), ('secondary-light', 'Secondary Light'), ('secondary-full', 'Secondary Full'), ('tertiary-light', 'Tertiary Light'), ('tertiary-full', 'Tertiary Full')]))]))], max_num=3))])), ('calendly', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('link', wagtail.core.blocks.URLBlock(required=False))])), ('articles', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('articles', wagtail.core.blocks.StreamBlock([('article', wagtail.core.blocks.PageChooserBlock(page_type=['cms.BlogPage'], required=False))], min_num=1))])), ('embed', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('embed', wagtail.core.blocks.StructBlock([('link', wagtail.core.blocks.URLBlock(required=False)), ('size', wagtail.core.blocks.ChoiceBlock(choices=[('xs', 'XS'), ('s', 'S'), ('m', 'M'), ('l', 'L'), ('x', 'X'), ('xl', 'XL'), ('full', 'Full')], required=False))]))])), ('social_share', webspace.cms.blocks.static.social_share.SocialShare()), ('table', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('rows', wagtail.core.blocks.StreamBlock([('cells', wagtail.core.blocks.StreamBlock([('text', wagtail.core.blocks.StructBlock([('value', wagtail.core.blocks.RichTextBlock(features=['h1', 'h2', 'h3', 'h4', 'bold', 'italic', 'link', 'ol', 'ul', 'hr', 'code-block', 'blockquote', 'strikethrough', 'mark'], required=False))])), ('svg', wagtail.core.blocks.StructBlock([('file', wagtail.documents.blocks.DocumentChooserBlock(required=False))])), ('image', wagtail.core.blocks.StructBlock([('file', wagtail.images.blocks.ImageChooserBlock(label='Image 500x500', required=False))]))], min_num=1))], min_num=1))])), ('accordion', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('items', wagtail.core.blocks.StreamBlock([('classic', wagtail.core.blocks.StructBlock([('head', wagtail.core.blocks.StructBlock([('value', wagtail.core.blocks.RichTextBlock(features=['h1', 'h2', 'h3', 'h4', 'bold', 'italic', 'link', 'ol', 'ul', 'hr', 'code-block', 'blockquote', 'strikethrough', 'mark'], required=False))], label='Head')), ('content', wagtail.core.blocks.StructBlock([('value', wagtail.core.blocks.RichTextBlock(features=['h1', 'h2', 'h3', 'h4', 'bold', 'italic', 'link', 'ol', 'ul', 'hr', 'code-block', 'blockquote', 'strikethrough', 'mark'], required=False))], label='Head'))]))], min_num=1))])), ('numbers', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('items', wagtail.core.blocks.StreamBlock([('classic', wagtail.core.blocks.StructBlock([('number', wagtail.core.blocks.IntegerBlock(required=True)), ('unit', wagtail.core.blocks.CharBlock(help_text='unité de mesure', required=False)), ('content', wagtail.core.blocks.StructBlock([('value', wagtail.core.blocks.RichTextBlock(features=['h1', 'h2', 'h3', 'h4', 'bold', 'italic', 'link', 'ol', 'ul', 'hr', 'code-block', 'blockquote', 'strikethrough', 'mark'], required=False))], label='Content'))]))], min_num=1))])), ('form', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('form', wagtail.core.blocks.StructBlock([('form', wagtail.snippets.blocks.SnippetChooserBlock('cms.Form', required=True))]))]))], blank=True)),
                ('feed_image', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image', verbose_name='SEO - Image')),
            ],
            options={
                'abstract': False,
            },
            bases=('wagtailcore.page',),
        ),
        migrations.CreateModel(
            name='Menu',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('help_text', models.CharField(blank=True, default='', max_length=100)),
                ('title', models.CharField(max_length=100)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Navigation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('help_text', models.CharField(blank=True, default='', max_length=100)),
                ('footer', wagtail.core.fields.StreamField([('menu', wagtail.snippets.blocks.SnippetChooserBlock('cms.Menu', required=False))], blank=True)),
                ('header_menus', wagtail.core.fields.StreamField([('menu', wagtail.snippets.blocks.SnippetChooserBlock('cms.Menu', required=False))], blank=True)),
                ('header_buttons', wagtail.core.fields.StreamField([('button', wagtail.core.blocks.StructBlock([('text', wagtail.core.blocks.CharBlock(required=False)), ('link', wagtail.core.blocks.URLBlock(required=False)), ('page', wagtail.core.blocks.PageChooserBlock(required=False)), ('open_new_tab', wagtail.core.blocks.BooleanBlock(default=False, required=False)), ('type', wagtail.core.blocks.ChoiceBlock(choices=[('primary-light', 'Primary Light'), ('primary-full', 'Primary Full'), ('secondary-light', 'Secondary Light'), ('secondary-full', 'Secondary Full'), ('tertiary-light', 'Tertiary Light'), ('tertiary-full', 'Tertiary Full')]))]))], blank=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='BlogIndexPage',
            fields=[
                ('genericpage_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='cms.GenericPage')),
                ('bg_desktop', wagtail.core.fields.StreamField([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], blank=True)),
                ('bg_mobile', wagtail.core.fields.StreamField([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], blank=True)),
                ('h1', models.CharField(blank=True, default='', max_length=200)),
                ('first_text', wagtail.core.fields.RichTextField(blank=True, default='')),
            ],
            options={
                'abstract': False,
            },
            bases=(webspace.cms.amp.mixins.AmpMixin, 'cms.genericpage', models.Model),
        ),
        migrations.CreateModel(
            name='BlogPage',
            fields=[
                ('genericpage_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='cms.GenericPage')),
                ('cover', wagtail.core.fields.StreamField([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], blank=True)),
                ('bg_desktop', wagtail.core.fields.StreamField([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], blank=True)),
                ('bg_mobile', wagtail.core.fields.StreamField([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], blank=True)),
                ('date', models.DateTimeField(default=datetime.date.today, verbose_name='Date publication + tri')),
                ('date_updated', models.DateTimeField(blank=True, default=None, null=True, verbose_name='Date mise à jour')),
                ('intro', models.CharField(blank=True, default='', max_length=500)),
                ('intro_page', wagtail.core.fields.RichTextField(blank=True, default='')),
                ('h1', models.CharField(blank=True, default='', max_length=200)),
                ('related_blogs', wagtail.core.fields.StreamField([('article', wagtail.core.blocks.PageChooserBlock(page_type=['cms.BlogPage'], required=False))], blank=True)),
                ('author', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
            bases=(webspace.cms.amp.mixins.AmpMixin, webspace.cms.forms.abstract.FormMixin, 'cms.genericpage', models.Model),
        ),
        migrations.CreateModel(
            name='ContentPage',
            fields=[
                ('genericpage_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='cms.GenericPage')),
            ],
            options={
                'abstract': False,
            },
            bases=(webspace.cms.amp.mixins.AmpMixin, webspace.cms.forms.abstract.FormMixin, 'cms.genericpage', models.Model),
        ),
        migrations.CreateModel(
            name='HomePage',
            fields=[
                ('genericpage_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='cms.GenericPage')),
            ],
            options={
                'abstract': False,
            },
            bases=(webspace.cms.amp.mixins.AmpMixin, webspace.cms.forms.abstract.FormMixin, 'cms.genericpage', models.Model),
        ),
        migrations.CreateModel(
            name='WebspaceSettings',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('facebook', models.URLField(blank=True, help_text='Facebook page URL')),
                ('instagram', models.URLField(blank=True, help_text='Instagram page URL')),
                ('linkedin', models.URLField(blank=True, help_text='Linkedin page URL')),
                ('twitter', models.URLField(blank=True, help_text='Twitter page URL')),
                ('pinterest', models.URLField(blank=True, help_text='Pinterest page URL')),
                ('youtube', models.URLField(blank=True, help_text='Youtube page URL')),
                ('brand_name', models.CharField(blank=True, default='', max_length=100)),
                ('logo_header_primary', wagtail.core.fields.StreamField([('image', wagtail.images.blocks.ImageChooserBlock(label='Image - ratio 200x55')), ('svg', wagtail.documents.blocks.DocumentChooserBlock(label='Svg - ratio 200x55'))], blank=True)),
                ('logo_header_secondary', wagtail.core.fields.StreamField([('image', wagtail.images.blocks.ImageChooserBlock(label='Image - ratio 200x55')), ('svg', wagtail.documents.blocks.DocumentChooserBlock(label='Svg - ratio 200x55'))], blank=True)),
                ('ga_code', models.CharField(blank=True, default='', help_text='Google Analytics - Code de suivis', max_length=100)),
                ('language', models.CharField(blank=True, choices=[('fr', 'French'), ('en', 'English')], default='', help_text='Language du site', max_length=100)),
                ('collect_text', wagtail.core.fields.RichTextField(blank=True, default='', help_text="Text qui apparait lorsqu'une personne doit accepter les CGU ou autre")),
                ('social_share_text', wagtail.core.fields.RichTextField(blank=True, default='', help_text='Text qui apparait sur un block Social Share')),
                ('vat_id', models.CharField(blank=True, default='', max_length=100)),
                ('legal_name', models.CharField(blank=True, default='', max_length=100)),
                ('founding_date', models.DateField(blank=True, default=None, null=True)),
                ('contact_phone', models.CharField(blank=True, default='', max_length=100)),
                ('contact_email', models.CharField(blank=True, default='', max_length=100)),
                ('area_served', models.CharField(blank=True, default='', max_length=100)),
                ('location_street_address', models.CharField(blank=True, default='', max_length=100)),
                ('location_address_locality', models.CharField(blank=True, default='', max_length=100)),
                ('location_postal_code', models.CharField(blank=True, default='', max_length=100)),
                ('location_address_country', models.CharField(blank=True, default='', max_length=100)),
                ('founding_location', models.CharField(blank=True, default='', max_length=100)),
                ('favicon', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image', verbose_name='Favicon')),
                ('logo_schema', models.ForeignKey(blank=True, help_text='Logo pour les Schemas Google', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image', verbose_name='Logo Entreprise')),
                ('newsletter', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='cms.Form', verbose_name='Newsletter Formulaire')),
                ('site', models.OneToOneField(editable=False, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.Site')),
            ],
            options={
                'verbose_name': 'Base',
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='MyDocument',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=255, verbose_name='title')),
                ('file', models.FileField(upload_to='documents', verbose_name='file')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='created at')),
                ('file_size', models.PositiveIntegerField(editable=False, null=True)),
                ('file_hash', models.CharField(blank=True, editable=False, max_length=40)),
                ('width', models.IntegerField(blank=True, default=None, help_text='for SVG', null=True)),
                ('height', models.IntegerField(blank=True, default=None, help_text='for SVG', null=True)),
                ('collection', models.ForeignKey(default=wagtail.core.models.get_root_collection_id, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='wagtailcore.Collection', verbose_name='collection')),
                ('tags', taggit.managers.TaggableManager(blank=True, help_text=None, through='taggit.TaggedItem', to='taggit.Tag', verbose_name='tags')),
                ('uploaded_by_user', models.ForeignKey(blank=True, editable=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL, verbose_name='uploaded by user')),
            ],
            options={
                'abstract': False,
            },
            bases=(wagtail.search.index.Indexed, models.Model),
        ),
        migrations.CreateModel(
            name='MultiLanguagePage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('sort_order', models.IntegerField(blank=True, editable=False, null=True)),
                ('language', models.CharField(blank=True, choices=[('fr', 'French'), ('en', 'English')], default='', help_text='Language de la page', max_length=100)),
                ('page', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailcore.Page', verbose_name='Page')),
                ('parent', modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='language_pages', to='cms.GenericPage')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='MenuItem',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('sort_order', models.IntegerField(blank=True, editable=False, null=True)),
                ('link_title', models.CharField(blank=True, max_length=50, null=True)),
                ('link_url', models.CharField(blank=True, max_length=500)),
                ('open_in_new_tab', models.BooleanField(blank=True, default=False)),
                ('link_page', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='wagtailcore.Page')),
                ('menu', modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='menu_items', to='cms.Menu')),
            ],
            options={
                'verbose_name': 'Icon',
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='IconSnippet',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key', models.CharField(max_length=255)),
                ('light', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='cms.MyDocument')),
                ('space', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='cms.MyDocument')),
            ],
            options={
                'verbose_name': 'Icon',
                'abstract': False,
            },
            bases=(wagtail.search.index.Indexed, models.Model),
        ),
        migrations.AddField(
            model_name='genericpage',
            name='navigation',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='cms.Navigation', verbose_name='Navigation'),
        ),
        migrations.CreateModel(
            name='Founders',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('sort_order', models.IntegerField(blank=True, editable=False, null=True)),
                ('name', models.CharField(blank=True, default='', max_length=100)),
                ('gender', models.CharField(blank=True, choices=[('Male', 'Male'), ('Female', 'Female')], default='', max_length=100)),
                ('same_as', models.URLField(blank=True)),
                ('nationality', models.CharField(blank=True, default='', max_length=100)),
                ('settings', modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='founders', to='cms.WebspaceSettings')),
            ],
            options={
                'verbose_name': 'Founder',
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FormSubmission',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('form_data', models.TextField()),
                ('submit_time', models.DateTimeField(auto_now_add=True, verbose_name='submit time')),
                ('form', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='submissions_form', to='cms.Form')),
                ('page', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='submissions_page', to='wagtailcore.Page')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FormField',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('sort_order', models.IntegerField(blank=True, editable=False, null=True)),
                ('label', models.CharField(help_text='The label of the form field', max_length=255, verbose_name='label')),
                ('field_type', models.CharField(choices=[('singleline', 'Single line text'), ('multiline', 'Multi-line text'), ('email', 'Email'), ('number', 'Number'), ('url', 'URL'), ('checkbox', 'Checkbox'), ('checkboxes', 'Checkboxes'), ('dropdown', 'Drop down'), ('multiselect', 'Multiple select'), ('radio', 'Radio buttons'), ('date', 'Date'), ('datetime', 'Date/time'), ('hidden', 'Hidden field')], max_length=16, verbose_name='field type')),
                ('required', models.BooleanField(default=True, verbose_name='required')),
                ('choices', models.TextField(blank=True, help_text='Comma separated list of choices. Only applicable in checkboxes, radio and dropdown.', verbose_name='choices')),
                ('default_value', models.CharField(blank=True, help_text='Default value. Comma separated values supported for checkboxes.', max_length=255, verbose_name='default value')),
                ('help_text', models.CharField(blank=True, max_length=255, verbose_name='help text')),
                ('placeholder', models.CharField(blank=True, max_length=255, verbose_name='Placeholder')),
                ('form', modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='form_fields', to='cms.Form')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DocumentPage',
            fields=[
                ('page_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='wagtailcore.Page')),
                ('document', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='cms.MyDocument')),
            ],
            options={
                'abstract': False,
            },
            bases=('wagtailcore.page',),
        ),
        migrations.CreateModel(
            name='BlogPageTag',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tag', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='cms_blogpagetag_items', to='taggit.Tag')),
                ('content_object', modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='tagged_items', to='cms.BlogPage')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='blogpage',
            name='tags',
            field=modelcluster.contrib.taggit.ClusterTaggableManager(blank=True, help_text='A comma-separated list of tags.', through='cms.BlogPageTag', to='taggit.Tag', verbose_name='Tags'),
        ),
    ]



from wagtail.core.blocks import StaticBlock
from webspace.cms.blocks.mocker import Mocker

from webspace.cms import constants


class SocialLinks(Mocker, StaticBlock):
    class Meta:
        template = '%s/static/social_links.html' % constants.BLOCK_TEMPLATES_PATH
        label = "Social Links"

    def mock(self, *args, **kwargs):
        self.mock_data.update({
            'type': 'social_links',
            'value': {}
        })
        return super().mock(*args, **kwargs)



from wagtail.core import blocks
from webspace.cms.blocks.common import EntryBlock
from webspace.cms import constants


class CalendlyEntry(EntryBlock):
    link = blocks.URLBlock(required=False)

    class Meta:
        template = '%s/entries/calendly.html' % constants.BLOCK_TEMPLATES_PATH
        label = "Calendly"

    def mock(self, *args, **kwargs):
        self.mock_data.update({
            'type': 'calendly',
            'value': {
                'link': "https://calendly.com/station-spatiale/30min?hide_event_type_details=1&background_color=20202C&text_color=F7F7F7&primary_color=2FB196"
            }
        })
        return super().mock(*args, **kwargs)



from __future__ import unicode_literals
import six
import sys
import gzip
import mimetypes
from fs import path
from django.apps import apps
from django.conf import settings
from django.utils.encoding import smart_text
from .. import DEFAULT_GZIP_CONTENT_TYPES
from django.test.client import RequestFactory


class BuildableMixin(object):
    fs_name = apps.get_app_config("bakery").filesystem_name
    fs = apps.get_app_config("bakery").filesystem

    def create_request(self, path):
        return RequestFactory().get(path)

    def get_content(self):
        return self.get(self.request).render().content

    def prep_directory(self, target_dir):
        dirname = path.dirname(target_dir)
        if dirname:
            dirname = path.join(settings.BUILD_DIR, dirname)
            if not self.fs.exists(dirname):
                self.fs.makedirs(dirname)

    def build_file(self, path, html):
        if self.is_gzippable(path):
            self.gzip_file(path, html)
        else:
            self.write_file(path, html)

    def write_file(self, target_path, html):
        with self.fs.open(smart_text(target_path), 'wb') as outfile:
            outfile.write(six.binary_type(html))
            outfile.close()

    def is_gzippable(self, path):
        if not getattr(settings, 'BAKERY_GZIP', False):
            return False
        whitelist = getattr(
            settings,
            'GZIP_CONTENT_TYPES',
            DEFAULT_GZIP_CONTENT_TYPES
        )
        return mimetypes.guess_type(path)[0] in whitelist

    def gzip_file(self, target_path, html):
        data_buffer = six.BytesIO()
        kwargs = dict(
            filename=path.basename(target_path),
            mode='wb',
            fileobj=data_buffer
        )
        if float(sys.version[:3]) >= 2.7:
            kwargs['mtime'] = 0
        with gzip.GzipFile(**kwargs) as f:
            f.write(six.binary_type(html))

        with self.fs.open(smart_text(target_path), 'wb') as outfile:
            outfile.write(data_buffer.getvalue())
            outfile.close()



from urllib.request import urlopen

from django.db import models
from django.http import Http404
from django.http import HttpResponse

from wagtail.admin.edit_handlers import FieldPanel
from wagtail.core.models import Page
from wagtail.documents.edit_handlers import DocumentChooserPanel
from webspace.loader import get_model

MyDocument = get_model('cms', 'MyDocument')


class ADocumentPage(Page):
    document = models.ForeignKey(
        MyDocument,
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name='+',
    )

    content_panels = [
        FieldPanel('title'),
        FieldPanel('slug'),
        DocumentChooserPanel('document'),
    ]
    subpage_types = []

    def serve(self, request, *args, **kwargs):
        try:
            ct = 'application/pdf' if self.document.file_extension == 'pdf' else 'application/octet-stream'
            response = HttpResponse(urlopen(self.document.url).read(), content_type=ct)
            response['Content-Disposition'] = 'filename="' + self.document.filename
            return response
        except Exception:
            raise Http404("")

    class Meta:
        abstract = True
        app_label = 'cms'



from wagtail.images.models import Image
from django.db import models
from wagtail.admin.edit_handlers import TabbedInterface, ObjectList
from wagtail.admin.edit_handlers import FieldPanel
from wagtail.core.fields import RichTextField
from wagtail.images.edit_handlers import ImageChooserPanel
from modelcluster.models import ClusterableModel


class APerson(ClusterableModel):
    help_text = models.CharField(max_length=100, default='', blank=True)

    first_name = models.CharField(blank=True, max_length=200, default='')
    last_name = models.CharField(blank=True, max_length=200, default='')
    title = models.CharField(default='', max_length=200, blank=True, help_text='Titre')
    description = RichTextField(default='', blank=True, help_text='Bio')

    email_contact = models.CharField(blank=True, max_length=200, default='')

    facebook = models.URLField(blank=True, help_text='Facebook page URL')
    instagram = models.URLField(blank=True, help_text='Instagram page URL')
    linkedin = models.URLField(blank=True, help_text='Linkedin page URL')
    twitter = models.URLField(blank=True, help_text='Twitter page URL')
    pinterest = models.URLField(blank=True, help_text='Pinterest page URL')
    youtube = models.URLField(blank=True, help_text='Youtube page URL')
    calendly = models.URLField(blank=True, help_text='Calendly URL')

    image_miniature = models.ForeignKey(
        Image,
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name='+',
        verbose_name="Image Miniature",
    )
    image_presentation = models.ForeignKey(
        Image,
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name='+',
        verbose_name="Image Presentation",
    )

    general_panels = [
        FieldPanel('help_text'),
        FieldPanel('first_name'),
        FieldPanel('last_name'),
        FieldPanel('email_contact'),
        FieldPanel('title'),
        FieldPanel('description'),
    ]

    socials_panels = [
        FieldPanel('facebook'),
        FieldPanel('instagram'),
        FieldPanel('linkedin'),
        FieldPanel('twitter'),
        FieldPanel('youtube'),
        FieldPanel('pinterest'),
        FieldPanel('calendly'),
    ]

    images_panels = [
        ImageChooserPanel('image_miniature'),
        ImageChooserPanel('image_presentation'),
    ]

    edit_handler = TabbedInterface([
        ObjectList(general_panels, heading='General'),
        ObjectList(socials_panels, heading='Socials'),
        ObjectList(images_panels, heading='Images'),
    ])

    def __str__(self):
        return self.help_text

    class Meta:
        abstract = True
        app_label = 'cms'

    @property
    def full_name(self):
        return self.first_name + ' ' + self.last_name



from wagtail.core import blocks
from wagtail.snippets.blocks import SnippetChooserBlock

from webspace.cms import constants
from webspace.cms.blocks.common import \
    TextBlock, \
    EntryBlock, \
    ButtonBlock


class TimelineCustomBlock(TextBlock):
    icon = SnippetChooserBlock('cms.IconSnippet', required=True)
    buttons = blocks.StreamBlock(
        [
            ('button', ButtonBlock()),
        ],
        max_num=3,
        required=False
    )

    class Meta:
        template = '%s/common/text.html' % constants.BLOCK_TEMPLATES_PATH
        label = "Custom"


class TimeLineEntry(EntryBlock):
    animation = blocks.BooleanBlock(required=False, help_text="Animation")
    items = blocks.StreamBlock(
        [
            ('text', TextBlock()),
            ('custom', TimelineCustomBlock()),
        ],
        min_num=1
    )

    def mock(self, *args, **kwargs):
        item = {
            'type': 'text',
            'value': {
                'value': self.xs
            }
        }
        self.mock_data.update({
            'type': 'timeline',
            'value': {
                'items': [
                    item,
                    item,
                    item,
                    item,
                    item
                ]
            }
        })
        return super().mock(*args, **kwargs)

    class Meta:
        template = '%s/entries/timeline.html' % constants.BLOCK_TEMPLATES_PATH
        label = "Timeline"



from wagtail.contrib.settings.models import register_setting
from wagtail.snippets.models import register_snippet

from webspace.loader import is_model_registered

__all__ = []

from .document.abstract import AMyDocument

if not is_model_registered('cms', 'MyDocument'):
    class MyDocument(AMyDocument):
        pass


    __all__.append('MyDocument')

# Snippets

from .snippets.icon import AIconSnippet

if not is_model_registered('cms', 'IconSnippet'):
    @register_snippet
    class IconSnippet(AIconSnippet):
        pass


    __all__.append('IconSnippet')

from .snippets.menu import AMenu, AMenuItem

if not is_model_registered('cms', 'Menu'):
    @register_snippet
    class Menu(AMenu):
        pass


    __all__.append('Menu')

if not is_model_registered('cms', 'MenuItem'):
    class MenuItem(AMenuItem):
        pass


    __all__.append('MenuItem')

from .snippets.navigation import ANavigation

if not is_model_registered('cms', 'Navigation'):
    @register_snippet
    class Navigation(ANavigation):
        pass


    __all__.append('Navigation')

from .snippets.form import AForm, AFormField, AFormSubmission

if not is_model_registered('cms', 'Form'):
    @register_snippet
    class Form(AForm):
        pass


    __all__.append('Form')

if not is_model_registered('cms', 'FormField'):
    class FormField(AFormField):
        pass


    __all__.append('FormField')

if not is_model_registered('cms', 'FormSubmission'):
    class FormSubmission(AFormSubmission):
        pass


    __all__.append('FormSubmission')

from .snippets.person import APerson

if not is_model_registered('cms', 'Person'):
    @register_snippet
    class Person(APerson):
        pass


    __all__.append('Person')


from .snippets.gallery import AGallery

if not is_model_registered('cms', 'Gallery'):
    @register_snippet
    class Gallery(AGallery):
        pass


    __all__.append('Gallery')


#  Pages


from .pages._generic import AGenericPage

if not is_model_registered('cms', 'GenericPage'):
    class GenericPage(AGenericPage):
        pass


    __all__.append('GenericPage')

from .pages.blog import ABlogIndexPage, ABlogPage, ABlogPageTag

if not is_model_registered('cms', 'BlogPageTag'):
    class BlogPageTag(ABlogPageTag):
        pass


    __all__.append('BlogPageTag')

if not is_model_registered('cms', 'BlogIndexPage'):
    class BlogIndexPage(ABlogIndexPage):
        pass


    __all__.append('BlogIndexPage')

if not is_model_registered('cms', 'BlogPage'):
    class BlogPage(ABlogPage):
        pass


    __all__.append('BlogPage')

from .pages.content import AContentPage

if not is_model_registered('cms', 'ContentPage'):
    class ContentPage(AContentPage):
        pass


    __all__.append('ContentPage')

from .pages.home import AHomePage

if not is_model_registered('cms', 'HomePage'):
    class HomePage(AHomePage):
        pass


    __all__.append('HomePage')

from .pages.document import ADocumentPage

if not is_model_registered('cms', 'DocumentPage'):
    class DocumentPage(ADocumentPage):
        pass


    __all__.append('DocumentPage')

from .pages._generic import AMultiLanguagePage

if not is_model_registered('cms', 'MultiLanguagePage'):
    class MultiLanguagePage(AMultiLanguagePage):
        pass


    __all__.append('MultiLanguagePage')

from .pages.portfolio import APortfolioIndexPage, APortfolioPage, APortfolioPageTag

if not is_model_registered('cms', 'PortfolioPageTag'):
    class PortfolioPageTag(APortfolioPageTag):
        pass


    __all__.append('PortfolioPageTag')

if not is_model_registered('cms', 'PortfolioIndexPage'):
    class PortfolioIndexPage(APortfolioIndexPage):
        pass


    __all__.append('PortfolioIndexPage')

if not is_model_registered('cms', 'PortfolioPage'):
    class PortfolioPage(APortfolioPage):
        pass


    __all__.append('PortfolioPage')

#  Settings

from .settings.webspace import AWebspaceSettings, AFounders

if not is_model_registered('cms', 'WebspaceSettings'):
    @register_setting
    class WebspaceSettings(AWebspaceSettings):
        pass


    __all__.append('WebspaceSettings')

if not is_model_registered('cms', 'Founders'):
    class Founders(AFounders):
        pass


    __all__.append('Founders')



from datetime import date
import re
import readtime
from lxml import etree

from django.shortcuts import render
from django.db import models
from django.conf import settings

from wagtail.admin.edit_handlers import FieldPanel
from wagtail.core import fields
from wagtail.core.models import Page
from wagtail.admin.edit_handlers import StreamFieldPanel
from wagtail.core.fields import StreamField
from wagtail.core import blocks
from wagtail.images.blocks import ImageChooserBlock
from wagtail.documents.blocks import DocumentChooserBlock

from modelcluster.fields import ParentalKey
from modelcluster.tags import ClusterTaggableManager
from taggit.models import TaggedItemBase

from webspace.bakery.abstract import WagtailPageBakeryModel
from webspace.cms import constants
from webspace.cms.amp.mixins import AmpMixin
from webspace.cms.forms.abstract import FormMixin
from webspace.loader import get_model, get_class

from ._mixins import TagMixin

GenericPage = get_model('cms', 'GenericPage')
Person = get_model('cms', 'Person')

TextEntry = get_class('cms.blocks.entries', 'TextEntry')


class ABlogPageTag(TaggedItemBase):
    content_object = ParentalKey('BlogPage', related_name='tagged_items')

    class Meta:
        app_label = 'cms'
        abstract = True


class ABlogPage(AmpMixin, FormMixin, WagtailPageBakeryModel, GenericPage):
    template = '%s/blog_page.html' % constants.PAGES_TEMPLATES_PATH
    author = models.ForeignKey(
        Person,
        blank=True,
        null=True,
        on_delete=models.SET_NULL,
    )
    cover = StreamField([
        ('image', ImageChooserBlock()),
        ('svg', DocumentChooserBlock()),
    ], blank=True)
    bg_desktop = StreamField([
        ('image', ImageChooserBlock()),
        ('svg', DocumentChooserBlock()),
    ], blank=True)
    bg_mobile = StreamField([
        ('image', ImageChooserBlock()),
        ('svg', DocumentChooserBlock()),
    ], blank=True)
    tags = ClusterTaggableManager(through='BlogPageTag', blank=True)
    date = models.DateTimeField("Date publication + tri", default=date.today)
    date_updated = models.DateTimeField("Date mise à jour", default=None, null=True, blank=True)
    intro = models.CharField(
        default='',
        max_length=500,
        blank=True,
        help_text="Texte d'introduction qui s'affiche sur un block article de présentation"
    )
    intro_page = fields.RichTextField(
        default='',
        blank=True,
        features=settings.RICH_TEXT_FEATURES,
        help_text="Texte qui s'affiche sur un la page de l'article"
    )
    h1 = models.CharField('Titre intro', default='', max_length=200, blank=True)
    related_blogs = StreamField([
        ('article', blocks.PageChooserBlock(required=False, target_model='cms.BlogPage')),
    ], blank=True)

    promote_panels = GenericPage.promote_panels + [
        StreamFieldPanel('schemas'),
    ]
    content_panels = [
                         StreamFieldPanel('bg_desktop'),
                         StreamFieldPanel('bg_mobile'),
                         StreamFieldPanel('cover'),
                         FieldPanel('author'),
                         FieldPanel('date'),
                         FieldPanel('date_updated'),
                         FieldPanel('tags'),
                         FieldPanel('h1'),
                         FieldPanel('intro'),
                         FieldPanel('intro_page'),
                         StreamFieldPanel('related_blogs'),
                     ] + GenericPage.content_panels

    class Meta:
        abstract = True
        app_label = 'cms'

    @property
    def blog_index(self):
        return self.get_ancestors().type(ABlogIndexPage).last()

    @property
    def read_time(self):
        rgx = re.compile(r'<.*?>')
        words = ""
        for block in self.body:
            if isinstance(block.block, TextEntry):
                text = block.value['text']['value'].source
                words += " " + rgx.sub('', text)
        return readtime.of_text(words)

    def get_absolute_url(self):
        return self.full_url

    def get_context(self, request, *args, **kwargs):
        context = super(ABlogPage, self).get_context(request)
        try:
            html = render(
                request,
                self.get_template(request, *args, **kwargs),
                context
            )
            tree = etree.HTML(html.content)
            summary = []
            for node in tree.xpath('//h2|//h3|//h4|//h5'):
                if node.attrib.get('id'):
                    if node.tag == 'h2':
                        summary.append({
                            'content': node.text,
                            'link': node.attrib.get('id'),
                            'h3': []
                        })
                    if node.tag == 'h3':
                        summary[-1]['h3'].append({
                            'content': node.text,
                            'link': node.attrib.get('id'),
                            'h4': []
                        })
                    """
                    if node.tag == 'h4':
                        summary[-1]['h3'][-1]['h4'].append({
                            'content': node.text,
                            'link': node.attrib.get('id'),
                        })
                    """
            context['summary'] = summary
        except Exception:
            context['summary'] = None
        return context


class ABlogIndexPage(TagMixin, AmpMixin, FormMixin, WagtailPageBakeryModel, GenericPage):
    subpage_types = ['BlogPage']
    template = '%s/blog_index_page.html' % constants.PAGES_TEMPLATES_PATH
    bg_desktop = StreamField([
        ('image', ImageChooserBlock()),
        ('svg', DocumentChooserBlock()),
    ], blank=True)
    bg_mobile = StreamField([
        ('image', ImageChooserBlock()),
        ('svg', DocumentChooserBlock()),
    ], blank=True)
    h1 = models.CharField(default='', max_length=200, blank=True)
    first_text = fields.RichTextField(default='', blank=True, features=settings.RICH_TEXT_FEATURES)

    content_panels = [
                         StreamFieldPanel('bg_desktop'),
                         StreamFieldPanel('bg_mobile'),
                         FieldPanel('h1'),
                         FieldPanel('first_text'),
                     ] + Page.content_panels

    class Meta:
        abstract = True
        app_label = 'cms'



# Generated by Django 3.0.7 on 2020-07-02 17:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0002_auto_20200702_1608'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='user',
            name='cover',
        ),
        migrations.AddField(
            model_name='user',
            name='description',
            field=models.TextField(blank=True, default='', help_text='Description'),
        ),
    ]



# Generated by Django 3.0.7 on 2020-07-02 17:58

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailimages', '0022_uploadedimage'),
        ('account', '0003_auto_20200702_1747'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='image_presentation',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image', verbose_name='Image presentation'),
        ),
        migrations.AlterField(
            model_name='user',
            name='description',
            field=models.TextField(blank=True, default='', help_text='Bio'),
        ),
    ]



# Generated by Django 3.0.7 on 2020-07-02 16:08

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailimages', '0022_uploadedimage'),
        ('account', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='cover',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image', verbose_name='Formulaire'),
        ),
        migrations.AddField(
            model_name='user',
            name='facebook',
            field=models.URLField(blank=True, help_text='Facebook page URL'),
        ),
        migrations.AddField(
            model_name='user',
            name='instagram',
            field=models.URLField(blank=True, help_text='Instagram page URL'),
        ),
        migrations.AddField(
            model_name='user',
            name='linkedin',
            field=models.URLField(blank=True, help_text='Linkedin page URL'),
        ),
        migrations.AddField(
            model_name='user',
            name='pinterest',
            field=models.URLField(blank=True, help_text='Pinterest page URL'),
        ),
        migrations.AddField(
            model_name='user',
            name='twitter',
            field=models.URLField(blank=True, help_text='Twitter page URL'),
        ),
        migrations.AddField(
            model_name='user',
            name='youtube',
            field=models.URLField(blank=True, help_text='Youtube page URL'),
        ),
    ]



# Generated by Django 3.0.7 on 2020-07-02 18:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0004_auto_20200702_1758'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='calendly',
            field=models.URLField(blank=True, help_text='Calendly URL'),
        ),
        migrations.AddField(
            model_name='user',
            name='title',
            field=models.CharField(blank=True, default='', help_text='Titre', max_length=200),
        ),
    ]



from django.core.management.base import BaseCommand
from ...utils import get_test_account


class Command(BaseCommand):
    help = 'Account commands : test'

    def add_arguments(self, parser):
        parser.add_argument('action', type=str)
        parser.add_argument('extra', type=str, nargs='?', default='')

    def handle(self, *args, **options):
        eval('self.' + options['action'] + '(' + options['extra'] + ')')
        get_test_account()



from wagtail.core import blocks
from .. import constants


class ThemeChoiceBlock(blocks.ChoiceBlock):
    choices = constants.THEME_CHOICES
    default = constants.THEME_SPACE


class SizeChoiceBlock(blocks.ChoiceBlock):
    choices = constants.SIZE_CHOICES
    default = constants.SIZE_M


class ContainerChoiceBlock(blocks.ChoiceBlock):
    choices = constants.CONTAINER_CHOICES
    default = constants.CONTAINER_REGULAR


class ButtonChoiceBlock(blocks.ChoiceBlock):
    choices = constants.BUTTON_CHOICES
    default = constants.BUTTON_PRIMARY


class AlignTextChoiceBlock(blocks.ChoiceBlock):
    choices = constants.ALIGN_TEXT_CHOICES
    default = constants.ALIGN_TEXT_NULL


class BackgroundPositionChoiceBlock(blocks.ChoiceBlock):
    choices = constants.BACKROUND_POSITION_CHOICES
    default = constants.BACKROUND_POSITION_CENTER




from wagtail.core.fields import StreamField

from .email import EmailAction


class ActionManager(object):

    def __init__(self):
        pass

    def get_actions(self):
        return StreamField([
            ('email', EmailAction()),
        ], blank=True)



import json
import random
from io import BytesIO
import requests

from django.core.files.images import ImageFile
from django.utils import lorem_ipsum

from wagtail.images.models import Image
from wagtail.contrib.forms.models import FORM_FIELD_CHOICES

from webspace.loader import get_model
from webspace.cms import constants


def title():
    return lorem_ipsum.words(random.randint(2, 15))


def text(rand_min=5, rand_max=20):
    return lorem_ipsum.words(random.randint(rand_min, rand_max))


class Mocker(object):
    MyDocument = get_model('cms', 'MyDocument')

    def __init__(self):
        super().__init__()
        self.mock_data = {}
        self.random_counter = 0

    def mock(self, bg=False, padding=True, container='regular', theme=constants.THEME_SPACE):
        if bg:
            bg_desktop = self.SVG_BG_DESKTOP_LIGHT if theme == constants.THEME_LIGHT else self.SVG_BG_DESKTOP_SPACE
            bg_mobile = self.SVG_BG_MOBILE_LIGHT if theme == constants.THEME_LIGHT else self.SVG_BG_MOBILE_SPACE
            self.mock_data['value'].update({
                'bg_desktop': [{
                    'type': 'svg',
                    'value': self.file(bg_desktop).id if bg else None
                }],
                'bg_mobile': [{
                    'type': 'svg',
                    'value': self.file(bg_mobile).id if bg else None
                }]
            })
        self.mock_data['value'].update({
            'theme': theme,
            'container': container,
            'padding': padding
        })
        copy = self.mock_data.copy()
        self.mock_data = {}
        self.random_counter += 1
        return copy

    p = f"""
        <p>{title()}</p>
        """

    h = f"""{title()}"""

    h1 = f"""
        <h1>{title()}</h1>
        """

    xs = f"""
            <h3>{title()}</h3>
            <p>{text(10, 10)}</p>
            """

    small = f"""
            <h2>{title()}</h2>
            <h3>{title()}</h3>
            <hr/>
            <p>{text(20, 20)}</p>
            """

    normal = f"""
        <h3>{title()}</h3>
        <hr/>
        <p>{text(50, 50)}</p>
        """

    example = f"""
        <h1>H1 -> Lorem ipsum dolor sit amet, consectetur adipiscing elit</h1>
        <h2>H2 -> Lorem ipsum dolor sit amet, consectetur adipiscing elit</h2>
        <h3>H3 -> Lorem ipsum dolor sit amet, consectetur adipiscing elit</h3>
        <h4>H4 -> Lorem ipsum dolor sit amet, consectetur adipiscing elit</h4>
        <h5>H5 -> Lorem ipsum dolor sit amet, consectetur adipiscing elit</h5>
        <h6>H6 -> Lorem ipsum dolor sit amet, consectetur adipiscing elit</h6>
        <hr/>
        <p>Paragraph -> {title()}</p>
        <p><b>Bold -> {title()}</b></p>
        <p><i>Italic -> {title()}</i></p>
        <p><strong>Strong -> {title()}</strong></p>
        """

    text_first_content = f"""
        <h2>Lorem ipsum dolor sit amet, consectetur adipiscing elit</h2>
        <hr/>
        <p>{title()}</p>
        """

    URL_TEST = "https://stationspatiale.com"
    URL_EMBED = "https://www.youtube.com/watch?time_continue=1&v=UoXQIR8ykEY&feature=emb_logo"

    #  Bg desktop
    IMG_FAVICON = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/icon_space.png",
        'title': "IMG_FAVICON",
        'name': "IMG_FAVICON.svg",
        'model': Image
    }

    #  Bg desktop
    SVG_BG_DESKTOP_LIGHT = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/bg-desktop_light.svg",
        'title': "SVG_BG_DESKTOP_LIGHT",
        'name': "SVG_BG_DESKTOP_LIGHT.svg",
        'model': MyDocument
    }
    IMG_BG_DESKTOP_LIGHT = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/bg-desktop_light.png",
        'title': "IMG_BG_DESKTOP_LIGHT",
        'name': "IMG_BG_DESKTOP_LIGHT.png",
        'model': Image
    }
    SVG_BG_DESKTOP_SPACE = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/bg-desktop_space.svg",
        'title': "SVG_BG_DESKTOP_SPACE",
        'name': "SVG_BG_DESKTOP_SPACE.svg",
        'model': MyDocument
    }
    IMG_BG_DESKTOP_SPACE = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/bg-desktop_space.png",
        'title': "IMG_BG_DESKTOP_SPACE",
        'name': "IMG_BG_DESKTOP_SPACE.png",
        'model': Image
    }

    #  Bg mobile
    SVG_BG_MOBILE_LIGHT = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/bg-mobile_light.svg",
        'title': "SVG_BG_MOBILE_LIGHT",
        'name': "SVG_BG_MOBILE_LIGHT.svg",
        'model': MyDocument
    }
    IMG_BG_MOBILE_LIGHT = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/bg-mobile_light.png",
        'title': "IMG_BG_MOBILE_LIGHT",
        'name': "IMG_BG_MOBILE_LIGHT.png",
        'model': Image
    }
    SVG_BG_MOBILE_SPACE = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/bg-mobile_space.svg",
        'title': "SVG_BG_MOBILE_SPACE",
        'name': "SVG_BG_MOBILE_SPACE.svg",
        'model': MyDocument
    }
    IMG_BG_MOBILE_SPACE = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/bg-mobile_space.png",
        'title': "IMG_BG_MOBILE_SPACE",
        'name': "IMG_BG_MOBILE_SPACE.png",
        'model': Image
    }

    # Logo
    SVG_LOGO_LIGHT = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/logo_light.svg",
        'title': "SVG_LOGO_LIGHT",
        'name': "SVG_LOGO_LIGHT.svg",
        'model': MyDocument
    }
    IMG_LOGO_LIGHT = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/logo_light.png",
        'title': "IMG_LOGO_LIGHT",
        'name': "IMG_LOGO_LIGHT.png",
        'model': Image
    }
    SVG_LOGO_SPACE = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/logo_space.svg",
        'title': "SVG_LOGO_SPACE",
        'name': "SVG_LOGO_SPACE.svg",
        'model': MyDocument

    }
    IMG_LOGO_SPACE = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/logo_space.png",
        'title': "IMG_LOGO_SPACE",
        'name': "IMG_LOGO_SPACE.png",
        'model': Image
    }

    # Blog cover  

    SVG_BLOG_COVER_LIGHT = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/blog-cover_light.svg",
        'title': "SVG_BLOG_COVER_LIGHT",
        'name': "SVG_BLOG_COVER_LIGHT.svg",
        'model': MyDocument
    }
    IMG_BLOG_COVER_LIGHT = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/blog-cover_light.png",
        'title': "IMG_BLOG_COVER_LIGHT",
        'name': "IMG_BLOG_COVER_LIGHT.png",
        'model': Image
    }
    SVG_BLOG_COVER_SPACE = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/blog-cover_space.svg",
        'title': "SVG_BLOG_COVER_SPACE",
        'name': "SVG_BLOG_COVER_SPACE.svg",
        'model': MyDocument
    }
    IMG_BLOG_COVER_SPACE = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/blog-cover_space.png",
        'title': "IMG_BLOG_COVER_SPACE",
        'name': "IMG_BLOG_COVER_SPACE.png",
        'model': Image
    }

    # Square  

    SVG_SQUARE_LIGHT = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/media-text_light.svg",
        'title': "SVG_SQUARE_LIGHT",
        'name': "SVG_SQUARE_LIGHT.svg",
        'model': MyDocument

    }
    IMG_SQUARE_LIGHT = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/media-text_light.png",
        'title': "IMG_SQUARE_LIGHT",
        'name': "IMG_SQUARE_LIGHT.png",
        'model': Image
    }
    SVG_SQUARE_SPACE = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/media-text_space.svg",
        'title': "SVG_SQUARE_SPACE",
        'name': "SVG_SQUARE_SPACE.svg",
        'model': MyDocument

    }
    IMG_SQUARE_SPACE = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/media-text_space.png",
        'title': "IMG_SQUARE_SPACE",
        'name': "IMG_SQUARE_SPACE.png",
        'model': Image
    }

    # Icon  

    SVG_ICON_LIGHT = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/icon_light.svg",
        'title': "SVG_ICON_LIGHT",
        'name': "SVG_ICON_LIGHT.svg",
        'model': MyDocument

    }
    IMG_ICON_LIGHT = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/icon_light.png",
        'title': "IMG_ICON_LIGHT",
        'name': "IMG_ICON_LIGHT.png",
        'model': Image
    }
    SVG_ICON_SPACE = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/icon_space.svg",
        'title': "SVG_ICON_SPACE",
        'name': "SVG_ICON_SPACE.svg",
        'model': MyDocument

    }
    IMG_ICON_SPACE = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/icon_space.png",
        'title': "IMG_ICON_SPACE",
        'name': "IMG_ICON_SPACE.png",
        'model': Image
    }

    # Content height

    SVG_CONTENT_HEIGHT_LIGHT = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/content-height_light.svg",
        'title': "SVG_CONTENT_HEIGHT_LIGHT",
        'name': "SVG_CONTENT_HEIGHT_LIGHT.svg",
        'model': MyDocument

    }
    IMG_CONTENT_HEIGHT_LIGHT = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/content-height_light.png",
        'title': "IMG_CONTENT_HEIGHT_LIGHT",
        'name': "IMG_CONTENT_HEIGHT_LIGHT.png",
        'model': Image
    }
    SVG_CONTENT_HEIGHT_SPACE = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/content-height_space.svg",
        'title': "SVG_CONTENT_HEIGHT_SPACE",
        'name': "SVG_CONTENT_HEIGHT_SPACE.svg",
        'model': MyDocument

    }
    IMG_CONTENT_HEIGHT_SPACE = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/content-height_space.png",
        'title': "IMG_CONTENT_HEIGHT_SPACE",
        'name': "IMG_CONTENT_HEIGHT_SPACE.png",
        'model': Image
    }

    # Content width

    SVG_CONTENT_WIDTH_LIGHT = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/content-width_light.svg",
        'title': "SVG_CONTENT_WIDTH_LIGHT",
        'name': "SVG_CONTENT_WIDTH_LIGHT.svg",
        'model': MyDocument
    }
    IMG_CONTENT_WIDTH_LIGHT = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/content-width_light.png",
        'title': "IMG_CONTENT_WIDTH_LIGHT",
        'name': "IMG_CONTENT_WIDTH_LIGHT.png",
        'model': Image
    }
    SVG_CONTENT_WIDTH_SPACE = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/content-width_space.svg",
        'title': "SVG_CONTENT_WIDTH_SPACE",
        'name': "SVG_CONTENT_WIDTH_SPACE.svg",
        'model': MyDocument
    }
    IMG_CONTENT_WIDTH_SPACE = {
        'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/content-width_space.png",
        'title': "IMG_CONTENT_WIDTH_SPACE",
        'name': "IMG_CONTENT_WIDTH_SPACE.png",
        'model': Image
    }

    IMGS_LIGHT = [
        IMG_SQUARE_LIGHT,
        IMG_LOGO_LIGHT,
        IMG_ICON_LIGHT,
        IMG_BG_DESKTOP_LIGHT,
        IMG_BG_MOBILE_LIGHT,
        IMG_BLOG_COVER_LIGHT,
        IMG_CONTENT_HEIGHT_LIGHT,
        IMG_CONTENT_WIDTH_LIGHT
    ]

    IMGS_SPACE = [
        IMG_SQUARE_SPACE,
        IMG_LOGO_SPACE,
        IMG_ICON_SPACE,
        IMG_BG_DESKTOP_SPACE,
        IMG_BG_MOBILE_SPACE,
        IMG_BLOG_COVER_SPACE,
        IMG_CONTENT_HEIGHT_SPACE,
        IMG_CONTENT_WIDTH_SPACE
    ]

    five = lorem_ipsum.words(5)
    hun = lorem_ipsum.words(100)
    animation = {
        'effect': 'fade-right',
        'duration': '1500'
    }
    default_url = "http://localhost:8080"

    @property
    def big(self):
        return f"""
                <h2>{title()}</h2>
                <h3>{title()}</h3>
                <h4>{title()}</h4>
                <hr/>
                <p>{title()}</p>
                <ol>
                    <li>{title()}</li>
                    <li>{title()}</li>
                    <li>{title()}</li>
                    <li>{title()}</li>
                </ol>
                <p>{title()}</p>
                <p><b>{title()}</b><i>{title()}</i></p>
                <p><i>{title()}</i></p>
                <ul>
                    <li>{title()}</li>
                    <li>{title()}</li>
                    <li>{title()}</li>
                    <li>{title()}</li>
                </ul>
                <p></p>
                <p></p>
                <p>{text()}</p>
                <p><a href="#">{title()}</a>. {text()}</p><p><br/></p>
                """

    @staticmethod
    def button(m_type=constants.BUTTON_PRIMARY_FULL):
        return {
            'text': 'Click here',
            'type': m_type
        }

    @staticmethod
    def file(img):
        try:
            ret = img['model'].objects.get(title=img['title'])
            return ret
        except img['model'].DoesNotExist:
            response = requests.get(img['url'])
            file = ImageFile(BytesIO(response.content), name=img['name'])
            ret = img['model'](
                title=img['title'],
                file=file
            )
            ret.save()
            return ret

    @staticmethod
    def menu(page, menu_id=None):
        Menu = get_model('cms', 'Menu')
        MenuItem = get_model('cms', 'MenuItem')

        if not menu_id:
            menu = Menu.objects.create(
                help_text=page.title,
                title=page.title
            )
            menu.save()
            menu_id = menu.id
        menu_item = MenuItem.objects.create(
            menu_id=menu_id,
            link_title=page.title,
            link_page_id=page.id
        )
        menu_item.save()
        return menu_id

    @staticmethod
    def add_menu(page, menu_id, footer=True):
        Navigation = get_model('cms', 'Navigation')
        nav, created = Navigation.objects.get_or_create(help_text='demo')
        if created:
            nav.save()

        # Header

        header_menus = []
        for header_menu in nav.header_menus:
            if menu_id != header_menu.value.id:
                header_menus.append({
                    'type': 'menu',
                    'value': header_menu.value.id
                })
        header_menus.append({
            'type': 'menu',
            'value': menu_id
        })
        nav.header_menus = json.dumps(header_menus)

        # Footer

        if footer:
            footer_menus = []
            for footer_menu in nav.footer:
                if menu_id != footer_menu.value.id:
                    footer_menus.append({
                        'type': 'menu',
                        'value': footer_menu.value.id
                    })
            footer_menus.append({
                'type': 'menu',
                'value': menu_id
            })
            nav.footer = json.dumps(footer_menus)

        nav.save()
        page.navigation = nav
        page.save()

    @staticmethod
    def add_header_buttons(page):
        header_buttons = [{
            'type': 'button',
            'value': Mocker.button(m_type=constants.BUTTON_PRIMARY)
        }, {
            'type': 'button',
            'value': Mocker.button(m_type=constants.BUTTON_SECONDARY)
        }]
        page.header_buttons = json.dumps(header_buttons)
        page.save()

    @staticmethod
    def get_form(key, nb_fields=None, head_text=True):
        Form = get_model('cms', 'Form')
        FormField = get_model('cms', 'FormField')
        IconSnippet = get_model('cms', 'IconSnippet')

        form, created = Form.objects.get_or_create(help_text=key)
        counter = 0
        if created:
            if head_text:
                form.text = Mocker.text_first_content
            form.save()
            for field_type in FORM_FIELD_CHOICES:
                form_field, created = FormField.objects.get_or_create(
                    field_type=field_type[0],
                    form_id=form.id
                )
                if created:
                    form_field.label = Mocker.h + str(counter)
                    form_field.help_text = Mocker.h
                    form_field.choices = 'loreum,dolor,sit,amet'
                    form_field.placeholder = 'loreum dolor sit amet'
                    form_field.required = False
                    form_field.icon = IconSnippet.objects.first()
                    form_field.save()
                counter += 1
                if nb_fields:
                    if counter >= nb_fields:
                        break
        return form

    @staticmethod
    def get_gallery(theme=constants.THEME_SPACE):
        Gallery = get_model('cms', 'Gallery')
        gallery, created = Gallery.objects.get_or_create(
            help_text=theme
        )
        if created:
            imgs = []
            all = Mocker.IMGS_LIGHT if theme == constants.THEME_LIGHT else Mocker.IMGS_SPACE
            for img in all:
                imgs.append({
                    'type': 'image',
                    'value': Mocker.file(img).id
                })
            gallery.medias = json.dumps(imgs)
            gallery.save()
        return gallery

    @staticmethod
    def get_person():
        Person = get_model('cms', 'Person')
        person, created = Person.objects.get_or_create(help_text='demo')
        if created:
            person.first_name = 'John'
            person.last_name = 'Doe'
            person.title = '<p>Sales Director</p>'
            person.description = Mocker.text_first_content
            person.email_contact = 'john@doe.com'

            person.facebook = 'https://stationspatiale.com'
            person.instagram = 'https://stationspatiale.com'
            person.linkedin = 'https://stationspatiale.com'
            person.twitter = 'https://stationspatiale.com'
            person.pinterest = 'https://stationspatiale.com'
            person.youtube = 'https://stationspatiale.com'
            person.calendly = 'https://stationspatiale.com'

            person.image_miniature = Mocker.file(Mocker.IMG_ICON_LIGHT)
            person.image_presentation = Mocker.file(Mocker.IMG_ICON_LIGHT)

            person.save()
        return person



from wagtail.core import blocks


from webspace.cms import constants
from webspace.cms.blocks.common import \
    SvgBlock, \
    ImageBlock, \
    EntryBlock


class SvgLabel(SvgBlock):
    label = blocks.CharBlock(required=False)
    page = blocks.PageChooserBlock(required=False)
    link = blocks.URLBlock(required=False)


class ImageLabel(ImageBlock):
    label = blocks.CharBlock(required=False)
    page = blocks.PageChooserBlock(required=False)
    link = blocks.URLBlock(required=False)


class MediasLineEntry(EntryBlock):
    medias = blocks.StreamBlock(
        [
            ('svg_label', SvgLabel()),
            ('image_label', ImageLabel()),
        ],
        min_num=1
    )

    def mock(self, nb_media=6, *args, **kwargs):
        if 'theme' in kwargs:
            icon = self.SVG_ICON_LIGHT \
                if kwargs['theme'] == constants.THEME_LIGHT else self.SVG_ICON_SPACE
        else:
            icon = self.SVG_ICON_SPACE
        media = {
            'type': 'svg_label',
            'value': {
                'file': self.file(icon).id,
                'label': self.h,
            }
        }
        i = 0
        medias = []
        while i < nb_media:
            medias.append(media)
            i += 1
        self.mock_data.update({
            'type': 'medias_line',
            'value': {
                'medias': medias
            }
        })
        return super().mock(*args, **kwargs)

    class Meta:
        template = '%s/entries/medias_line.html' % constants.BLOCK_TEMPLATES_PATH
        label = "Medias Line"



from django.template.response import SimpleTemplateResponse
from wagtail.core.views import serve as wagtail_serve

from .utils import activate_amp_mode


def serve(request, path):
    with activate_amp_mode():
        response = wagtail_serve(request, path)
        if isinstance(response, SimpleTemplateResponse):
            response.render()
        return response



from webspace.bakery.abstract import WagtailPageBakeryModel
from webspace.cms import constants
from webspace.cms.amp.mixins import AmpMixin
from webspace.loader import get_model
from webspace.cms.forms.abstract import FormMixin

GenericPage = get_model('cms', 'GenericPage')


class AHomePage(AmpMixin, FormMixin, WagtailPageBakeryModel, GenericPage):
    template = '%s/home_page.html' % constants.PAGES_TEMPLATES_PATH
    content_panels = GenericPage.content_panels

    subpage_types = [
        'cms.ContentPage',
        'cms.DocumentPage',
        'cms.BlogIndexPage',
        'cms.PortfolioIndexPage',
    ]

    class Meta:
        abstract = True
        app_label = 'cms'



from django.db import models
from wagtail.admin.edit_handlers import StreamFieldPanel, FieldPanel
from wagtail.core.fields import StreamField
from wagtail.snippets.blocks import SnippetChooserBlock
from modelcluster.models import ClusterableModel
from webspace.loader import get_class


ButtonBlock = get_class('cms.blocks.common', 'ButtonBlock')
LinkBlock = get_class('cms.blocks.common', 'LinkBlock')
StreamCard = get_class('cms.blocks.entries', 'StreamCard')


class ANavigation(ClusterableModel):
    help_text = models.CharField(max_length=100, default='', blank=True)

    footer = StreamField([
        ('menu', SnippetChooserBlock('cms.Menu', required=False)),
        ('stream_card', StreamCard())
    ], blank=True, verbose_name="Footer items")

    header_menus = StreamField([
        ('menu', SnippetChooserBlock('cms.Menu', required=False)),
        ('link', LinkBlock())
    ], blank=True, verbose_name="Header items")

    header_buttons = StreamField([
        ('button', ButtonBlock())
    ], blank=True, verbose_name="Header button")

    panels = [
        FieldPanel("help_text"),
        StreamFieldPanel('header_menus'),
        StreamFieldPanel('header_buttons'),
        StreamFieldPanel('footer'),
    ]

    def __str__(self):
        return self.help_text

    class Meta:
        abstract = True
        app_label = 'cms'



import logging
from django.http import HttpResponse
from django.shortcuts import render

from webspace.cms import constants

from .celery import bakery_build, app
from .models import TaskBuild

logger = logging.getLogger('bakery')


def index(request):
    task = TaskBuild.objects.first()
    return render(
        request,
        '%s/bakery.html' % constants.ADMIN_TEMPLATES_PATH,
        {
            'cache_icon': 'cog',
            'ready': task.ready if task else True,
            'builds': TaskBuild.objects.all()[:5]
         },
    )


def build(request):
    task = TaskBuild.objects.first()
    if not task or task.ready:
        bakery_build.delay()
        return HttpResponse("Build is running !")
    else:
        return HttpResponse("Build is already running !")



# Generated by Django 3.0.9 on 2020-08-25 17:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0021_auto_20200825_1735'),
    ]

    operations = [
        migrations.AddField(
            model_name='webspacesettings',
            name='secondary_inverse_bg_color',
            field=models.CharField(blank=True, default='', max_length=20),
        ),
        migrations.AddField(
            model_name='webspacesettings',
            name='secondary_inverse_color_uks',
            field=models.CharField(blank=True, default='', max_length=20),
        ),
    ]



from django.db import models
from wagtail.contrib.settings.models import BaseSetting
from wagtail.admin.edit_handlers import TabbedInterface, ObjectList
from wagtail.admin.edit_handlers import FieldPanel
from wagtail.admin.edit_handlers import StreamFieldPanel
from wagtail.core.fields import StreamField, RichTextField
from wagtail.images.edit_handlers import ImageChooserPanel
from wagtail.documents.blocks import DocumentChooserBlock
from wagtail.images.blocks import ImageChooserBlock
from modelcluster.fields import ParentalKey
from modelcluster.models import ClusterableModel
from wagtail.core.models import Orderable
from wagtail.admin.edit_handlers import InlinePanel
from wagtail.snippets.edit_handlers import SnippetChooserPanel

from webspace.loader import get_model
from webspace.cms import constants

Form = get_model('cms', 'Form')


class AFounders(Orderable):
    settings = ParentalKey("WebspaceSettings", related_name="founders")
    name = models.CharField(default='', blank=True, max_length=100)
    gender = models.CharField(choices=[
        ('Male', 'Male'),
        ('Female', 'Female'),
    ], default='', blank=True, max_length=100)
    same_as = models.URLField(blank=True)
    nationality = models.CharField(default='', blank=True, max_length=100)

    general_panels = [
        FieldPanel('name'),
        FieldPanel('gender'),
        FieldPanel('same_as'),
        FieldPanel('nationality'),
    ]

    class Meta:
        verbose_name = 'Founder'
        abstract = True
        app_label = 'cms'


class AWebspaceSettings(BaseSetting, ClusterableModel):
    facebook = models.URLField(blank=True, help_text='Facebook page URL')
    instagram = models.URLField(blank=True, help_text='Instagram page URL')
    linkedin = models.URLField(blank=True, help_text='Linkedin page URL')
    twitter = models.URLField(blank=True, help_text='Twitter page URL')
    pinterest = models.URLField(blank=True, help_text='Pinterest page URL')
    youtube = models.URLField(blank=True, help_text='Youtube page URL')

    brand_name = models.CharField(default='', blank=True, max_length=100)
    brand_short_name = models.CharField(default='', blank=True, max_length=100)
    brand_description = models.TextField(default='', blank=True)

    primary_color_uks = models.CharField(default='', blank=True, max_length=20)
    primary_bg_color = models.CharField(default='', blank=True, max_length=20)
    primary_inverse_color_uks = models.CharField(default='', blank=True, max_length=20)
    primary_inverse_bg_color = models.CharField(default='', blank=True, max_length=20)
    secondary_color_uks = models.CharField(default='', blank=True, max_length=20)
    secondary_bg_color = models.CharField(default='', blank=True, max_length=20)
    secondary_inverse_color_uks = models.CharField(default='', blank=True, max_length=20)
    secondary_inverse_bg_color = models.CharField(default='', blank=True, max_length=20)

    logo_header_primary = StreamField([
        ('image', ImageChooserBlock(label="Image - ratio 200x55")),
        ('svg', DocumentChooserBlock(label="Svg - ratio 200x55")),
    ], blank=True)
    logo_header_secondary = StreamField([
        ('image', ImageChooserBlock(label="Image - ratio 200x55")),
        ('svg', DocumentChooserBlock(label="Svg - ratio 200x55")),
    ], blank=True)

    logo_schema = models.ForeignKey(
        'wagtailimages.Image',
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name='+',
        verbose_name="Logo Entreprise",
        help_text="Logo pour les Schemas Google"
    )
    favicon = models.ForeignKey(
        'wagtailimages.Image',
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name='+',
        verbose_name="Favicon",
    )
    ga_code = models.CharField(
        default='',
        blank=True,
        max_length=100,
        help_text="Google Analytics - Code de suivis"
    )
    language = models.CharField(
        choices=constants.LANGUAGES,
        default='',
        blank=True,
        max_length=100,
        help_text="Language du site"
    )
    collect_text = RichTextField(
        blank=True,
        default='',
        help_text="Text qui apparait lorsqu'une personne doit accepter les CGU ou autre"
    )
    social_share_text = RichTextField(
        blank=True,
        default='',
        help_text="Text qui apparait sur un block Social Share"
    )
    social_links_text = RichTextField(
        blank=True,
        default='',
        help_text="Text qui apparait sur un block Social Links"
    )
    newsletter = models.ForeignKey(
        Form,
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name='+',
        verbose_name="Newsletter Formulaire",
    )

    vat_id = models.CharField(default='', blank=True, max_length=100)
    legal_name = models.CharField(default='', blank=True, max_length=100)
    founding_date = models.DateField(blank=True, default=None, null=True)
    contact_phone = models.CharField(default='', blank=True, max_length=100)
    contact_email = models.CharField(default='', blank=True, max_length=100)
    area_served = models.CharField(default='', blank=True, max_length=100)
    location_street_address = models.CharField(default='', blank=True, max_length=100)
    location_address_locality = models.CharField(default='', blank=True, max_length=100)
    location_postal_code = models.CharField(default='', blank=True, max_length=100)
    location_address_country = models.CharField(default='', blank=True, max_length=100)
    founding_location = models.CharField(default='', blank=True, max_length=100)

    summary_text = RichTextField(
        blank=True,
        default='',
        help_text="Text qui apparait en haut du sommaire"
    )
    search_text = RichTextField(
        blank=True,
        default='',
        help_text="Text qui apparait en haut de la recherche par tag"
    )
    related_articles_text = RichTextField(
        blank=True,
        default='',
        help_text="Text qui apparait en haut des articles en lien"
    )
    button_view_all_articles = models.CharField(default='', blank=True, max_length=100)

    related_portfolios_text = RichTextField(
        blank=True,
        default='',
        help_text="Text qui apparait en haut des portfolios en lien"
    )
    button_view_all_portfolios = models.CharField(default='', blank=True, max_length=100)



    multi_header = models.BooleanField(
        default=True,
        help_text="Ajoute le choix des langages dans le header"
    )
    multi_footer = models.BooleanField(
        default=True,
        help_text="Ajoute le choix des langages dans le footer"
    )



    general_panels = [
        FieldPanel('language'),
        FieldPanel('ga_code'),
        FieldPanel('collect_text'),
        SnippetChooserPanel('newsletter')
    ]

    blog_panels = [
        FieldPanel('summary_text'),
        FieldPanel('search_text'),
        FieldPanel('related_articles_text'),
        FieldPanel('button_view_all_articles')
    ]

    portfolio_panels = [
        FieldPanel('related_portfolios_text'),
        FieldPanel('button_view_all_portfolios')
    ]

    socials_panels = [
        FieldPanel('social_share_text'),
        FieldPanel('social_links_text'),
        FieldPanel('facebook'),
        FieldPanel('instagram'),
        FieldPanel('linkedin'),
        FieldPanel('twitter'),
        FieldPanel('youtube'),
        FieldPanel('pinterest'),
    ]

    brand_tab_panels = [
        FieldPanel('brand_name'),
        FieldPanel('brand_short_name'),
        FieldPanel('brand_description'),

        FieldPanel('primary_color_uks'),
        FieldPanel('primary_bg_color'),
        FieldPanel('primary_inverse_color_uks'),
        FieldPanel('primary_inverse_bg_color'),

        FieldPanel('secondary_color_uks'),
        FieldPanel('secondary_bg_color'),
        FieldPanel('secondary_inverse_color_uks'),
        FieldPanel('secondary_inverse_bg_color'),

        StreamFieldPanel('logo_header_primary'),
        StreamFieldPanel('logo_header_secondary'),
        ImageChooserPanel('favicon'),
        ImageChooserPanel('logo_schema'),
    ]

    organization_panels = [
        FieldPanel('vat_id'),
        FieldPanel('legal_name'),
        FieldPanel('founding_date'),
        FieldPanel('contact_phone'),
        FieldPanel('contact_email'),
        FieldPanel('area_served'),
        FieldPanel('location_street_address'),
        FieldPanel('location_address_locality'),
        FieldPanel('location_postal_code'),
        FieldPanel('location_address_country'),
        FieldPanel('founding_location'),
        InlinePanel("founders", label="Founders")
    ]

    multi_panels = [
        FieldPanel('multi_header'),
        FieldPanel('multi_footer'),
    ]

    edit_handler = TabbedInterface([
        ObjectList(general_panels, heading='General'),
        ObjectList(brand_tab_panels, heading='Brand'),
        ObjectList(organization_panels, heading='Organization'),
        ObjectList(socials_panels, heading='Socials'),
        ObjectList(blog_panels, heading='Articles'),
        ObjectList(portfolio_panels, heading='Portfolio'),
        ObjectList(multi_panels, heading='Multilingue'),
    ])

    class Meta:
        verbose_name = 'Base'
        abstract = True
        app_label = 'cms'

    @property
    def locale(self):
        return constants.LOCALES[self.language] if self.language in constants.LOCALES else ''



from django.db import models
from wagtail.search import index
from wagtail.admin.edit_handlers import FieldPanel
from wagtail.documents.edit_handlers import DocumentChooserPanel

from webspace.loader import get_model


MyDocument = get_model('cms', 'MyDocument')


class AIconSnippet(index.Indexed, models.Model):
    DEFAULT_LINK = '/static/webspace/img/svg/default.svg'
    key = models.CharField(max_length=255)
    light = models.ForeignKey(
        MyDocument,
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name='+',
        verbose_name="Theme Secondary"
    )
    space = models.ForeignKey(
        MyDocument,
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name='+',
        verbose_name="Theme Primary"
    )

    panels = [
        FieldPanel('key'),
        DocumentChooserPanel('space'),
        DocumentChooserPanel('light'),
    ]

    search_fields = [
        index.SearchField('key', partial_match=True),
    ]

    def __str__(self):
        return self.key

    @staticmethod
    def get_context():
        IconSnippet = get_model('cms', 'IconSnippet')
        ret = {}
        for icon in IconSnippet.objects.all():
            ret[icon.key] = {
                'space': icon.space.url if icon.space else IconSnippet.DEFAULT_LINK,
                'light': icon.light.url if icon.light else IconSnippet.DEFAULT_LINK,
            }
        return ret

    class Meta:
        verbose_name = "Icon"
        abstract = True
        app_label = 'cms'

